<?php
/**
 * DFU Business Accelerator functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package DFU_Business_Accelerator
 *******************************************************************************************************************************************/

if ( ! function_exists( 'dfu_busacc_fn_setup' ) ) {
	function dfu_busacc_fn_setup() {
		// Make theme available for translation.
		load_theme_textdomain( 'dfu-busacc', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'dfu_busacc_custom_background_args',
				array(
					'default-color'      => 'ffffff',
					'default-image'      => '',
					'wp-head-callback'   => ( get_theme_mod( 'dba_bgimg_responsive', false ) ? 'dfu_busacc_fn_custom_background_cb' : '_custom_background_cb' ),
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 80,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);

		// Set up the WordPress core custom header feature.
		add_theme_support(
			'custom-header',
			apply_filters(
				'dfu_busacc_custom_header_args',
				array(
					'default-image'      => get_parent_theme_file_uri( '/inc/assets/img/334581-pxhere.jpg' ),
					'header-text'        => true,
					'default-text-color' => '222',
					'width'              => 2000,
					'height'             => 1200,
					'flex-width'         => true,
					'flex-height'        => true,
					'uploads'            => true,
					'random-default'     => true,
				)
			)
		);

		register_default_headers(
			array(
				'image1' => array(
					'url'           => '%s/inc/assets/img/1046491-pxhere.jpg',
					'thumbnail_url' => '%s/inc/assets/img/1046491-pxhere.jpg',
					'description'   => __( 'Image1', 'dfu-busacc' ),
				),
				'notebook2' => array(
					'url'           => '%s/inc/assets/img/334581-pxhere.jpg',
					'thumbnail_url' => '%s/inc/assets/img/334581-pxhere.jpg',
					'description'   => __( 'Image2', 'dfu-busacc' ),
				),
			)
		);

		// Add theme support for post formats
		add_theme_support( 'post-formats', array( 'aside', 'gallery', 'link', 'image', 'quote', 'video' ) );

		// Add theme support for editor styles
		$font_url = str_replace( ',', '%2C', '//fonts.googleapis.com/css?family=Montserrat:300,400,700' );
		add_editor_style( array( $font_url, get_template_directory_uri() . '/inc/css/editor-style.min.css' ) );

		// Add image sizes
		add_image_size( 'dfu-busacc-md', 580, 1100 );
		add_image_size( 'dfu-busacc-xl', 1200, 2200 );
	}
}
add_action( 'after_setup_theme', 'dfu_busacc_fn_setup' );

/**
 * Custom background callback with responive background image
 *******************************************************************************************************************************************/
function dfu_busacc_fn_custom_background_cb() {
    // $background is the saved custom image, or the default image.
    $background = set_url_scheme( get_background_image() );
    // $color is the saved custom color.
    // A default has to be specified in style.css. It will not be printed here.
    $color = get_background_color();
    if ( $color === get_theme_support( 'custom-background', 'default-color' ) ) {
        $color = false;
    }
    $type_attr = current_theme_supports( 'html5', 'style' ) ? '' : ' type="text/css"';
    if ( ! $background && ! $color ) {
        if ( is_customize_preview() ) {
            printf( '<style%s id="custom-background-css"></style>', $type_attr ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
        return;
    }
    $style = $color ? "background-color: #" . esc_attr( $color ) . ";" : '';
    if ( $background ) {
        // Background Position.
        $position_x = get_theme_mod( 'background_position_x', get_theme_support( 'custom-background', 'default-position-x' ) );
        $position_y = get_theme_mod( 'background_position_y', get_theme_support( 'custom-background', 'default-position-y' ) );
        if ( ! in_array( $position_x, array( 'left', 'center', 'right' ), true ) ) {
            $position_x = 'left';
        }
        if ( ! in_array( $position_y, array( 'top', 'center', 'bottom' ), true ) ) {
            $position_y = 'top';
        }
        $position = " background-position: $position_x $position_y;";
        // Background Size.
        $size = get_theme_mod( 'background_size', get_theme_support( 'custom-background', 'default-size' ) );
        if ( ! in_array( $size, array( 'auto', 'contain', 'cover' ), true ) ) {
            $size = 'auto';
        }
		$size = " background-size: $size;";
        // Background Repeat.
        $repeat = get_theme_mod( 'background_repeat', get_theme_support( 'custom-background', 'default-repeat' ) );
        if ( ! in_array( $repeat, array( 'repeat-x', 'repeat-y', 'repeat', 'no-repeat' ), true ) ) {
            $repeat = 'repeat';
        }
        $repeat = " background-repeat: $repeat;";
        // Background Scroll.
        $attachment = get_theme_mod( 'background_attachment', get_theme_support( 'custom-background', 'default-attachment' ) );
        if ( 'fixed' !== $attachment ) {
            $attachment = 'scroll';
        }
        $attachment = " background-attachment: " . esc_attr( $attachment ) .";";
        $style .= $position . $size . $repeat . $attachment;
    }
    ?>
	<style<?php echo $type_attr; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?> id="custom-background-css">
		body.custom-background { <?php echo trim( $style ); ?> }
		<?php
		if ( $background ) {
			$imgid = attachment_url_to_postid( $background );
			dfu_busacc_fn_get_reponsive_img_css( $imgid, 'body.custom-background', false, true );
		}
		?>
	</style>
<?php
}

function dfu_busacc_fn_register_menus() {
	// This theme uses wp_nav_menu() in multiple location.
	register_nav_menus( array(
		'main-menu' => esc_html__( 'Main', 'dfu-busacc' ),
		'footer-menu' => esc_html__( 'Footer', 'dfu-busacc' ),
	) );
}
add_action( 'init', 'dfu_busacc_fn_register_menus' );

// Add the custom size to the Gutenberg image dropdown
if ( ! function_exists( 'dfu_busacc_fn_add_image_size_names' ) ) {
	function dfu_busacc_fn_add_image_size_names( $sizes ) {
		return array_merge(
			$sizes,
			array(
				'dfu-busacc-md'    => __( 'dfu-busacc-medium', 'dfu-busacc' ),
				'dfu-busacc-xl'    => __( 'dfu-busacc-extra-large', 'dfu-busacc' ),
			)
		);
	}
}
add_filter( 'image_size_names_choose', 'dfu_busacc_fn_add_image_size_names' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 * Priority 0 to make it available to lower priority callbacks.
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_content_width' ) ) {
	function dfu_busacc_fn_content_width() {
		// This variable is intended to be overruled from themes.
		// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
		// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
		$GLOBALS['content_width'] = apply_filters( 'dfu_busacc_content_width', 1380 );
	}
}
add_action( 'after_setup_theme', 'dfu_busacc_fn_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_widgets_init' ) ) {
	function dfu_busacc_fn_widgets_init() {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Sidebar 1', 'dfu-busacc' ),
				'id'            => 'dba-sidebar-1',
				'description'   => esc_html__( 'Add widgets for sidebar 1.', 'dfu-busacc' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h2 class="dba-widget-title">',
				'after_title'   => '</h2>',
			)
		);

		/* Custom sidebars */
		$numsidebar = get_theme_mod( 'dba_sidebar_no', 0 );
		for ( $i = 0; $i < $numsidebar; $i++ ) {
			$num = $i + 1;
			register_sidebar(
				array(
					'name'          => esc_html__( 'Custom sidebar ', 'dfu-busacc' ) . $num,
					'id'            => 'dba-custom-sidebar-' . $num,
					'description'   => esc_html__( 'Add widgets for custom sidebar ', 'dfu-busacc' ) . $num,
					'before_widget' => '<section id="%1$s" class="widget %2$s">',
					'after_widget'  => '</section>',
					'before_title'  => '<h2 class="dba-widget-title">',
					'after_title'   => '</h2>',
				)
			);
		}

		/* Footer bar areas */
		$numfooterbar = get_theme_mod( 'dba_footerbar_no', 0 );
		for ( $j = 0; $j < $numfooterbar; $j++ ) {
			$num = $j + 1;
			register_sidebar(
				array(
					'name'          => esc_html__( 'Footer widget ', 'dfu-busacc' ) . $num,
					'id'            => 'dba-footerbar-' . $num,
					'description'   => esc_html__( 'Add widgets for footer bar ', 'dfu-busacc' ) . $num,
					'before_widget' => '<section id="%1$s" class="widget %2$s">',
					'after_widget'  => '</section>',
					'before_title'  => '<h2 class="dba-widget-title">',
					'after_title'   => '</h2>',
				)
			);
		}

		register_sidebar(
			array(
				'name'          => esc_html__( '404 Error sidebar', 'dfu-busacc' ),
				'id'            => 'dba-404-sidebar',
				'description'   => esc_html__( 'Add widgets for the 404 page to help get the relevant information.', 'dfu-busacc' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h2 class="dba-widget-title">',
				'after_title'   => '</h2>',
			)
		);

		register_sidebar(
			array(
				'name'          => esc_html__( 'Search sidebar', 'dfu-busacc' ),
				'id'            => 'dba-search-sidebar',
				'description'   => esc_html__( 'Add widgets here.', 'dfu-busacc' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h2 class="dba-widget-title">',
				'after_title'   => '</h2>',
			)
		);

		register_sidebar(
			array(
				'name'          => esc_html__( 'Blog sidebar', 'dfu-busacc' ),
				'id'            => 'dba-blog-sidebar',
				'description'   => esc_html__( 'Sidebar use in blog posts index page.', 'dfu-busacc' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h2 class="dba-widget-title">',
				'after_title'   => '</h2>',
			)
		);

		register_sidebar(
			array(
				'name'          => esc_html__( 'Top bar widgets 1', 'dfu-busacc' ),
				'id'            => 'dba-topbar-sidebar-1',
				'description'   => esc_html__( 'Add widgets here.', 'dfu-busacc' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h2 class="dba-widget-title">',
				'after_title'   => '</h2>',
			)
		);

		register_sidebar(
			array(
				'name'          => esc_html__( 'Top bar widgets 2', 'dfu-busacc' ),
				'id'            => 'dba-topbar-sidebar-2',
				'description'   => esc_html__( 'Add widgets here.', 'dfu-busacc' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h2 class="dba-widget-title">',
				'after_title'   => '</h2>',
			)
		);

		register_sidebar(
			array(
				'name'          => esc_html__( 'Homepage under CTA', 'dfu-busacc' ),
				'id'            => 'dba-home-head-sidebar',
				'description'   => esc_html__( 'Add widgets in homepage, must enabled in customiser\'s Home Page Setting. If no header image/CTA defined, this will appear under top navigation menu', 'dfu-busacc' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h2 class="dba-widget-title">',
				'after_title'   => '</h2>',
			)
		);

		if ( '2' == get_theme_mod( 'dba_header_layout', '1' ) ) {
			register_sidebar(
				array(
					'name'          => esc_html__( 'Header (type 2) widgets', 'dfu-busacc' ),
					'id'            => 'dba-headertype2-sidebar',
					'description'   => esc_html__( 'Add widgets here.', 'dfu-busacc' ),
					'before_widget' => '<section id="%1$s" class="widget %2$s">',
					'after_widget'  => '</section>',
					'before_title'  => '<h2 class="dba-widget-title">',
					'after_title'   => '</h2>',
				)
			);
		}
	}
}
add_action( 'widgets_init', 'dfu_busacc_fn_widgets_init' );

/**
 * Enqueue scripts and styles.
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_scripts' ) ) {
	function dfu_busacc_fn_scripts() {
		$path = get_template_directory_uri() . '/inc/';
		wp_enqueue_style( 'bootstrap', $path . 'css/bootstrap.min.css', array(), '4.6.0', 'all' );
		wp_enqueue_style( 'dfuba-theme-style', $path . 'css/theme-style.min.css', array(), wp_get_theme()->get( 'Version' ), 'all' );
		wp_enqueue_style( 'dfuba-style', get_stylesheet_uri(), array(), wp_get_theme()->get( 'Version' ), 'all' );

		wp_enqueue_script( 'dfuba-skip-link-focus-fix', $path . 'js/skip-link-focus-fix.js', array(), wp_get_theme()->get( 'Version' ), true );
		wp_enqueue_script( 'jquery-ui-core', '', array(), false, true );
		wp_enqueue_script( 'bootstrap-bundle-js', $path . 'js/bootstrap.bundle.min.js', array( 'jquery' ), '4.6.0', true );
		wp_enqueue_script( 'dfuba-custom-js', $path . 'js/theme-custom.js', array( 'jquery' ), wp_get_theme()->get( 'Version' ), true );
		if ( true == get_theme_mod( 'dba_load_fa', true ) ) {
			wp_enqueue_script( 'font-awesome-js', $path . 'js/all.min.js', array( 'jquery' ), '5.15.2', true );
		}

		// Load stickymenu js if enabled in customizer
		if ( true == get_theme_mod( 'dba_stickymenu', false ) ) {
			wp_enqueue_script( 'dfuba-stickymenu', $path . 'js/stickymenu.js', array( 'jquery' ), wp_get_theme()->get( 'Version' ), true );
		}
		// Load backtotop js if enabled in customizer
		if ( true == get_theme_mod( 'dba_show_backtotop', false ) ) {
			wp_enqueue_script( 'dfuba-backtotop', $path . 'js/backtotop.js', array( 'jquery' ), wp_get_theme()->get( 'Version' ), true );
		}
		// Load sticky single product summary
		if ( true == get_theme_mod( 'dba_wc_sglprod_sticky_summary', false ) ) {
			wp_enqueue_script( 'dfuba-stickyprodsummary', $path . 'js/stickyprodsummary.js', array( 'jquery' ), wp_get_theme()->get( 'Version' ), true );
		}

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
}
add_action( 'wp_enqueue_scripts', 'dfu_busacc_fn_scripts' );

/**
 * Enqueue the Gutenberg editor stylesheet.
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_enqueue_gblock' ) ) {
	function dfu_busacc_fn_enqueue_gblock() {
		wp_register_style( 'dfuba-gutenberg', get_stylesheet_directory_uri() . '/inc/css/gutenberg-editor-style.min.css' );
		wp_enqueue_style( 'dfuba-gutenberg' );
		$inlinecss = '';
		$inlinecss = '.editor-styles-wrapper h1 { font-size: 1.8rem; margin-bottom: 0.75rem; }';
		$inlinecss .= '.editor-styles-wrapper h2 { font-size: 1.6rem; margin-bottom: 0.75rem; }';
		$inlinecss .= '.editor-styles-wrapper blockquote { border: 0; }';
		wp_add_inline_style( 'dfuba-gutenberg', $inlinecss );
	}
}
add_action( 'enqueue_block_editor_assets', 'dfu_busacc_fn_enqueue_gblock' );

/**
 * Return an alternate title, without prefix, for every type used in the get_the_archive_title().
********************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_archive_title' ) ) {
	function dfu_busacc_fn_archive_title( $title ) {
		if ( is_category() ) {
			$title = single_cat_title( '', false );
		} elseif ( is_tag() ) {
			$title = single_tag_title( '', false );
		} elseif ( is_author() ) {
			$title = get_the_author();
		} elseif ( is_year() ) {
			$title = get_the_date( _x( 'Y', 'yearly archives date format', 'dfu-busacc' ) );
		} elseif ( is_month() ) {
			$title = get_the_date( _x( 'F Y', 'monthly archives date format', 'dfu-busacc' ) );
		} elseif ( is_day() ) {
			$title = get_the_date( _x( 'F j, Y', 'daily archives date format', 'dfu-busacc' ) );
		} elseif ( is_tax( 'post_format' ) ) {
			if ( is_tax( 'post_format', 'post-format-aside' ) ) {
				$title = _x( 'Asides', 'post format archive title', 'dfu-busacc' );
			} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
				$title = _x( 'Galleries', 'post format archive title', 'dfu-busacc' );
			} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
				$title = _x( 'Images', 'post format archive title', 'dfu-busacc' );
			} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
				$title = _x( 'Videos', 'post format archive title', 'dfu-busacc' );
			} elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
				$title = _x( 'Quotes', 'post format archive title', 'dfu-busacc' );
			} elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
				$title = _x( 'Links', 'post format archive title', 'dfu-busacc' );
			} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
				$title = _x( 'Statuses', 'post format archive title', 'dfu-busacc' );
			} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
				$title = _x( 'Audio', 'post format archive title', 'dfu-busacc' );
			} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
				$title = _x( 'Chats', 'post format archive title', 'dfu-busacc' );
			}
		} elseif ( is_post_type_archive() ) {
			$title = post_type_archive_title( '', false );
		} elseif ( is_tax() ) {
			$title = single_term_title( '', false );
		} else {
			$title = __( 'Archives', 'dfu-busacc' );
		}
		return $title;
	}
}
add_filter( 'get_the_archive_title', 'dfu_busacc_fn_archive_title' );

/**
 * Enable shortcode in menu
********************************************************************************************************************************************/
add_filter( 'wp_nav_menu_items', 'do_shortcode' );

/**
 * Filter the CSS class for a nav menu based on a condition.
 *
 * @param array  $classes The CSS classes that are applied to the menu item's <li> element.
 * @param object $item    The current menu item.
 * @return array (maybe) modified nav menu class.
********************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_add_nav_class' ) ) {
	function dfu_busacc_fn_add_nav_class( $classes, $item, $args ) {
		if ( 'footer-menu' === $args->theme_location ) {
			$classes[] = 'list-inline-item';
			if ( in_array( 'current-menu-item', $classes ) ) {
				$classes[] = 'active ';
			}
		}
		return $classes;
	}
}
add_filter( 'nav_menu_css_class', 'dfu_busacc_fn_add_nav_class', 10, 3 );

/**
 * 'Read more' link to post
********************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_excerpt_readmore' ) ) {
	function dfu_busacc_fn_excerpt_readmore( $more ) {
		if ( is_admin() ) {
			return $more;
		} else {
			return sprintf( ' ... <div class="dba-readmore"><a href="%1$s">%2$s</a></div>', esc_url( get_permalink( get_the_ID() ) ), __( 'Read More', 'dfu-busacc' ) );
		}
	}
}
add_filter( 'excerpt_more', 'dfu_busacc_fn_excerpt_readmore' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
********************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_body_classes' ) ) {
	function dfu_busacc_fn_body_classes( $classes ) {
		// Adds a class of hfeed to non-singular pages.
		if ( ! is_singular() ) {
			$classes[] = 'hfeed';
		}
		return $classes;
	}
}
add_filter( 'body_class', 'dfu_busacc_fn_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
********************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_pingback_header' ) ) {
	function dfu_busacc_fn_pingback_header() {
		if ( is_singular() && pings_open() ) {
			printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
		}
	}
}
add_action( 'wp_head', 'dfu_busacc_fn_pingback_header' );

/**
 * Customizer additions
 *******************************************************************************************************************************************/
require_once get_template_directory() . '/class/tgm/class-tgm-plugin-activation.php';
require_once get_template_directory() . '/inc/theme-options/class-dbabusacc-kirki.php';
require get_template_directory() . '/inc/theme-options/class-dba-customiser-controls.php';
require get_template_directory() . '/inc/theme-options/kirki-options.php';
if ( class_exists( 'woocommerce' ) ) {
	require get_template_directory() . '/inc/theme-options/kirki-wc-options.php';
}
/* Theme CSS from customiser */
require get_template_directory() . '/inc/theme-css.php';
add_action( 'wp_head', 'dfu_busacc_fn_custom_css' );
require get_template_directory() . '/inc/customizer.php';
do_action( 'dfu_busacc_a_add_options' ); // add additional Kirki options

/**
 * Required php files
 *******************************************************************************************************************************************/
require_once get_template_directory() . '/class/nav/class-bootstrap4-navwalker.php'; // Register Bootstrap 4 Navigation Walker
require get_template_directory() . '/inc/theme-cpt.php'; // Custom post types
require get_template_directory() . '/inc/theme-admin.php'; // Theme setup functions in admin
require get_template_directory() . '/inc/theme-functions.php';
require get_template_directory() . '/inc/theme-responsive.php';
require get_template_directory() . '/inc/theme-utilities.php';
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php'; // Load Jetpack compatibility file.
}
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/theme-wc.php'; // Load WooCommerce compatibility file.
}

/**
 * Register the recommended plugins for theme
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_register_recommended_plugins' ) ) {
	function dfu_busacc_fn_register_recommended_plugins() {
		$plugins = array(
			array(
				'name'        => __( 'Advanced custom fields (for theme custom fields)', 'dfu-busacc' ),
				'slug'        => 'advanced-custom-fields',
				'is_callable' => 'acf',
				'required'    => false,
			),
			array(
				'name'        => __( 'Kirki Customizer Framework (for theme options in customiser)', 'dfu-busacc' ),
				'slug'        => 'kirki',
				'required'    => false,
			),
			array(
				'name'        => __( 'Max Mega Menu (for mega menu)', 'dfu-busacc' ),
				'slug'        => 'megamenu',
				'required'    => false,
			),
			array(
				'name'        => __( 'WooCommerce (for E-commerce)', 'dfu-busacc' ),
				'slug'        => 'woocommerce',
				'required'    => false,
			),
		);

		$config = array(
			'id'            => 'dfu-busacc', // Unique ID for hashing notices for multiple instances of TGMPA.
			'default_path'  => '', // Default absolute path to bundled plugins.
			'menu'          => 'tgmpa-install-plugins', // Menu slug.
			'capability'	=> 'edit_theme_options',
			'has_notices'   => true, // Show admin notices or not.
			'dismissable'   => true, // If false, a user cannot dismiss the nag message.
			'dismiss_msg'   => '', // If 'dismissable' is false, this message will be output at top of nag.
			'is_automatic'  => false, // Automatically activate plugins after installation or not.
			'message'       => '', // Message to output right before the plugins table.
		);
		tgmpa( $plugins, $config );
	}
}
add_action( 'tgmpa_register', 'dfu_busacc_fn_register_recommended_plugins' );

/**
 * Unhide custom fields when using ACF
 *******************************************************************************************************************************************/
//add_filter( 'acf/settings/remove_wp_meta_box', '__return_false' );

/**
 * Disable ACF on Frontend
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_disable_acf_on_frontend' ) ) {
	function dfu_busacc_fn_disable_acf_on_frontend( $plugins ) {
		if ( is_admin() ) {
			return $plugins;
		}
		foreach ( $plugins as $i => $plugin ) {
			if ( 'advanced-custom-fields-pro/acf.php' == $plugin ) {
				unset( $plugins[ $i ] );
			}
		}
		return $plugins;
	}
}
add_filter( 'option_active_plugins', 'dfu_busacc_fn_disable_acf_on_frontend' );

/**
 * Action on theme upgrade completion
 *******************************************************************************************************************************************/
// add_action( 'upgrader_process_complete', 'dfu_busacc_fn_upgrade_complete', 10, 2 );
// function dfu_busacc_fn_upgrade_complete( $wp_upgrader, $hook_extra ){
// 	if ( 'update' == $hook_extra['action'] && 'theme' == $hook_extra['type'] ) {
// 		// upgrade from 1.0.10 to 1.0.11
// 		$wc_prod_per_row = get_theme_mod( 'dba_wc_max_prod_row', 3 );
// 		set_theme_mod( 'woocommerce_catalog_columns', $wc_prod_per_row );
// 		$wc_prod_per_page = get_theme_mod( 'dba_wc_max_prod_page', 12 );
// 		$wc_catalog_row = ceil( $wc_prod_per_page / $wc_prod_per_row );
// 		set_theme_mod( 'woocommerce_catalog_rows', $wc_catalog_row );
// 	}
// }