<?php

/**
 * Get sidebar
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_get_sidebar' ) ) {
	function dfu_busacc_fn_get_sidebar( $sidebar ) {
		switch ( $sidebar ) :
			case 'none':
				$sidebar = '';
				break;
			case 'default': // Theme default
				$sidebar = get_theme_mod( 'dba_default_sidebar' );
				if ( 'none' == $sidebar ) {
					$sidebar = '';
				}
		endswitch;
		return $sidebar;
	}
}

/**
 * Display sidebar
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_display_sidebar' ) ) {
	function dfu_busacc_fn_display_sidebar( $sidebar, $width ) {
		if ( is_active_sidebar( $sidebar ) ) {
			if ( '2' == $width ) {
				$colwidth = 'col-md-2';
			} elseif ( '3' == $width ) {
				$colwidth = 'col-md-3';
			} elseif ( '4' == $width ) {
				$colwidth = 'col-md-4';
			} elseif ( '5' == $width ) {
				$colwidth = 'col-md-5';
			} elseif ( '6' == $width ) {
				$colwidth = 'col-md-6';
			}
			$attr = array( 'type' => 1, 'itemscope' => 'itemscope', 'itemtype' => 'http://schema.org/WPSideBar' );
			?>

			<aside id="secondary" class="<?php echo esc_attr( $colwidth ); ?>" <?php echo apply_filters( 'dfu_busacc_f_sidebar_secondary_microdata', 'itemscope="' . esc_attr( $attr['itemscope'] ) . '" itemtype="' . esc_url( $attr['itemtype'] ) . '"' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>>
				<div id="widget" class="dba-widget-area">
					<div class="dba-sidebar">
						<?php
						do_action( 'dfu_busacc_a_before_sidebar' );
						dynamic_sidebar( $sidebar );
						do_action( 'dfu_busacc_a_after_sidebar' );
						?>
					</div><!-- dba-sidebar -->
				</div><!-- #widget -->
			</aside><!-- #secondary -->
			
		<?php
		}
	}
}

/**
 * Display horizontal sidebar/widgets
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_display_h_sidebar' ) ) {
	function dfu_busacc_fn_display_h_sidebar( $widgetoutercontainer, $widgetinnercontainer, $sidebarname, $bgcolor ) {
		if ( is_active_sidebar( $sidebarname ) ) :
			echo '<div class="' . esc_attr( $widgetoutercontainer ) . ' py-5"' . ( (!empty( $bgcolor ) )? 'style="background-color: ' . esc_attr( $bgcolor ) . '";' : '' ) . '>';
			if ( 'full-width' == $widgetoutercontainer && 'container' == $widgetinnercontainer ) {
				echo '<div class="container">';
			} else {
				echo '<div class="container-fluid">';
			}
			?>
					<div class="row">
						<div class="col-12">
							<?php dynamic_sidebar( $sidebarname ); ?>
						</div><!-- col -->
					</div><!-- row -->
				</div><!-- container -->
			</div><!-- cta widget -->
		<?php
		endif;
	}
}

/**
 * Get heading style
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_get_display_style' ) ) {
	function dfu_busacc_fn_get_display_style( $htype = 1 ) {
		if ( 1 == $htype ) { /* h1 */
			if ( function_exists( 'get_field' ) ) {
				$titlestyle = get_field( 'dbacf_title_style' );
			} else {
				$titlestyle = esc_html( get_post_meta( get_the_ID(), 'dbacf_title_style', true ) );
			}
			if ( $titlestyle && 'none' == $titlestyle ) {
				$titlestyle = '';
			}
			if ( $titlestyle && 'default' == $titlestyle ) {
				$defaulttitlestyle = get_theme_mod( 'dba_default_title_style' );
				$titlestyle = esc_attr( $defaulttitlestyle );
			}
		} elseif ( 2 == $htype ) { /* section title - h2 */
			if ( function_exists( 'get_field' ) ) {
				$titlestyle = get_field( 'dbacf_heading_style' );
			} else {
				$titlestyle = esc_html( get_post_meta( get_the_ID(), 'dbacf_heading_style', true ) );
			}
			if ( $titlestyle && 'none' == $titlestyle ) {
				$titlestyle = '';
			}
			if ( $titlestyle && 'default' == $titlestyle ) {
				$defaulttitlestyle = get_theme_mod( 'dba_default_head_style' );
				$titlestyle = esc_attr( $defaulttitlestyle );
			}
		}
		return $titlestyle;
	}
}

/**
 * Display bottom header
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_display_btm_header' ) ) {
	function dfu_busacc_fn_display_btm_header( $term = '', $pid = false ) {
		// $term can also be a post id
		if ( function_exists( 'get_field' ) ) {
			$headertype = get_field( 'dbacf_header_type', $term );
			if ( $headertype && ( 'img' == $headertype['value'] || 'bgcolour' == $headertype['value'] ) ) {
				if ( 'img' == $headertype['value'] ) {
					$headerimg = get_field( 'dbacf_header_img', $term );
					if ( $headerimg ) { //Image group
						$img_size = $headerimg['dbacf_bg_img_size'];
						// Image location
						$img_from = $headerimg['dbacf_img_from'];
						if ( $img_from && 'featured' == $img_from ) {
							if ( has_post_thumbnail() ) {
								$url = get_the_post_thumbnail_url( get_the_ID(), 'full' );
								$imgid = get_post_thumbnail_id();
							}
						} elseif ( 'upload' == $img_from ) {
							$upl_img = $headerimg['dbacf_upload_img'];
							if ( ! empty( $upl_img ) ) {
								$url = $upl_img['url'];
								$imgid = $upl_img['id'];
							}
						}
						// Image position
						$bg_pos = $headerimg['dbacf_bg_position'];
						if ( $bg_pos && 'x-y' == $bg_pos ) {
							$x_pos = $headerimg['dbacf_x_position'];
							$y_pos = $headerimg['dbacf_y_position'];
							$img_pos = $x_pos . '%' . ' ' . $y_pos . '%';
						} else {
							$img_pos = $bg_pos;
						}
						//Image filter
						$img_filter = $headerimg['dbacf_img_filter'];
						if ( $img_filter && 'none' !== $img_filter ) {
							$img_filter_pc = $headerimg['dbacf_img_filter_percent'];
							if ( $img_filter_pc ) {
								$img_filter_txt = $img_filter . '(' . $img_filter_pc . '%)';
							}
						}
						//Image background repeat
						$img_repeat = $headerimg['dbacf_bg_repeat'];
						if ( empty( $img_repeat ) ) {
							$img_repeat = 'no-repeat';
						}
					}
				}
				//Header
				$imgbgcolour = get_field( 'dbacf_header_bg_colour', $term );
				$img_width = get_field( 'dbacf_header_width', $term );
				if ( empty( $img_width ) ) {
					$img_width = 'full-width';
				}
				$img_ht = get_field( 'dbacf_header_height', $term );
				$mimg_ht = get_field( 'dbacf_header_smldev_height', $term );
				if ( ! $img_ht ) {
					$img_ht = 280;
				}
				//Titles
				$styles = '';
				$showheadertitle = get_field( 'dbacf_show_title_on_header', $term );
				$headertitlecolor = get_field( 'dbacf_title_colour_on_header', $term );
				$centertitle = get_field( 'dbacf_center_title', $term );
				if ( ! $centertitle ) {
					$hpos = get_field( 'dbacf_horizontal_pos', $term );
					if ( '' == $hpos ) {
						$hpos = 'left';
					}
					$vpos = get_field( 'dbacf_vertical_pos', $term );
					if ( '' == $vpos ) {
						$vpos = 'top';
					}
					$title_x = get_field( 'dbacf_title_x', $term );
					$title_y = get_field( 'dbacf_title_y', $term );
				}
				if ( $showheadertitle && true == $showheadertitle ) { // show title
					if ( ! $centertitle ) {
						$styles .= '.titlepos { position: absolute; ';
						$styles .= $hpos . ': ' . esc_attr( $title_x ) . 'px; ';
						$styles .= $vpos . ': ' . esc_attr( $title_y ) . 'px; }';
					} else {
						$styles .= '.titlepos { position: absolute; ';
						$styles .= 'top: 50%; left: 50%; transform: translate(-50%, -50%); }';
					}
					if ( ! empty( $headertitlecolor ) ) {
						$styles .= '.dba-img-title { color: ' . esc_attr( $headertitlecolor ) . '; }';
					}
				}
				// Subtitle
				$showsubtitle = get_field( 'dbacf_show_subtitle', $term );
				if ( $showsubtitle && true == $showsubtitle ) {
						$headersubtitle = get_field( 'dbacf_header_subtitle', $term );
						$showsubtitlefrom = $headersubtitle['dbacf_show_subtitle_from'];
						if ( $showsubtitlefrom ) {
							switch ( $showsubtitlefrom ) {
							case 'customtext':
								$subtitle = $headersubtitle['dbacf_subtitle'];
								break;
							case 'excerpt':
								if ( is_category() || is_tag() || is_author() ) {
									$subtitle = get_the_archive_description();
								} else {
									$subtitle = ( has_excerpt() ? get_the_excerpt() : '' );
								}
								break;
							case 'customfield':
								$customfieldname = $headersubtitle['dbacf_subtitle_field_name'];
								if ( $customfieldname ) {
									$subtitle = get_field( $customfieldname, $term );
								}
								break;
							}
						}
					if ( true == $showheadertitle ) { //show title & subtitle
						$styles .= '.subtitlepos { padding: 5px 10px 0 ; }';
					} elseif ( false == $showheadertitle ) { // show subtitle only
						if ( ! $centertitle ) {
							$styles .= '.subtitlepos { position: absolute; ';
							$styles .= $hpos . ': ' . esc_attr( $title_x ) . 'px; ';
							$styles .= $vpos . ': ' . esc_attr( $title_y ) . 'px; }';
						} else {
							$styles .= '.subtitlepos { position: absolute; ';
							$styles .= 'top: 50%; left: 50%; transform: translate(-50%, -50%); }';
						}
					}
					if ( ! empty( $headertitlecolor ) ) {
						$styles .= '.dba-img-subtitle { color: ' . esc_attr( $headertitlecolor ) . '; }';
					}
				}

				$styles .= '.dba-headerimg { position: relative; }';
				if ( 'img' == $headertype['value'] ) {
					$styles .= '.img-cover { ';
					$styles .= 'background-color: ' . esc_attr( $imgbgcolour ) . '; ';
					$styles .= 'background-size: ' . esc_attr( $img_size ) . '; ';
					$styles .= 'background-position: ' . esc_attr( $img_pos ) . '; ';
					$styles .= 'height: ' . esc_attr( $img_ht ) . 'px; ';
					$styles .= 'background-repeat: ' . esc_attr( $img_repeat ) . '; ';
					if ( $img_filter && 'none' !== $img_filter && $img_filter_pc ) {
						$styles .= 'filter: ' . esc_attr( $img_filter_txt ) . '; ';
						$styles .= '-webkit-filter: ' . esc_attr( $img_filter_txt ) . '; ';
					}
					$styles .= '}';
					$styles .= dfu_busacc_fn_get_reponsive_img_css( $imgid, '.img-cover' );
				} elseif ( 'bgcolour' == $headertype['value'] ) {
					$styles .= '.img-cover { ';
					$styles .= 'background-color: ' . esc_attr( $imgbgcolour ) . '; ';
					$styles .= 'height: ' . esc_attr( $img_ht ) . 'px; }';
				}
				$styles .= '@media screen and (max-width: 767px) { ';
				$styles .= '.img-cover { ';
				$styles .= 'height: ' . esc_attr( $mimg_ht ) . 'px; }';
				$styles .= '}';
				echo '<style type="text/css">';
				echo wp_kses_post( $styles );
				echo '</style>';

				if ( ( 'img' == $headertype['value'] && ! empty( $url ) ) || 'bgcolour' == $headertype['value'] ) {
				?>
					<section id="headerimg" class="dba-headerimg">
						<div class="<?php echo esc_attr( $img_width ); ?> px-0">
							<div class="row no-gutters">
								<div class="col">
									<div class="img-cover"></div><!-- img-cover -->
										<?php
										$titleonheader = get_field( 'dbacf_title_style_on_header', $term );
										if ( $titleonheader && 'none' == $titleonheader ) {
											$titleonheader = '';
										}
										if ( $titleonheader && 'default' == $titleonheader ) {
											$defaulttitlestyle = get_theme_mod( 'dba_default_title_style', 'none' );
											if ( 'none' == $defaulttitlestyle ) {
												$titleonheader = '';
											} else {
												$titleonheader = $defaulttitlestyle;
											}
										}
										if ( is_archive() ) {
											$title = get_the_archive_title();
										} elseif ( ! is_archive() ) {
											$title = get_the_title();
										}
										if ( $showheadertitle && true == $showheadertitle ) {
										?>
											<div class="titlepos"><h1 class="entry-title <?php echo esc_attr( $titleonheader ); ?> dba-img-title"><span><?php echo esc_html( $title ); ?></span></h1>
										<?php
										}
										if ( $showsubtitle && true == $showsubtitle ) {
										?>
											<h2 class="subtitlepos dba-img-subtitle"><?php echo wp_kses_post( $subtitle ); ?></h2>
										<?php
										}
										if ( $showheadertitle && true == $showheadertitle ) {
											echo '</div><!-- titlepos -->';
										}
										?>
								</div><!-- img-wrapper -->
							</div><!-- row -->
						</div><!-- container-fluid -->
					</section>
				<?php
				}
			} elseif ( $headertype && 'slider' == $headertype['value'] ) {
				$slider = get_field( 'dbacf_slider' );
				if ( $slider ) {
					$sliderwidth = $slider['dbacf_slider_width'];
					if ( $sliderwidth && 'full' == $sliderwidth ) {
					?>
						<section id="headerslider"><div class="container-fluid">
					<?php
					} elseif ( $sliderwidth && 'container' == $sliderwidth ) {
					?>
						<section id="headerslider"><div class="container">
					<?php
					}
					?>
							<div class="row">
								<?php
								$scode = $slider['dbacf_slider_shortcode'];
								if ( $scode ) {
									echo do_shortcode( esc_html( $scode ) );
								}
								?>
							</div><!-- row -->
						</div><!-- container-fluid -->
						</section>
				<?php
				}
			}
		} else { // ACF not available
			// if not taxonomy or a page id provided
			if ( empty( $term ) || true == $pid ) {
				if ( true == $pid ) {
					$cid = $term;
				} else {
					$cid = get_the_ID();
				}
				$headertype = get_post_meta( $cid, 'dbacf_header_type', true );
				if ( $headertype && ( 'img' == $headertype || 'bgcolour' == $headertype ) ) {
					if ( 'img' == $headertype ) {
						$img_size = get_post_meta( $cid, 'dbacf_header_img_dbacf_bg_img_size', true );
						// Image location
						$img_from = get_post_meta( $cid, 'dbacf_header_img_dbacf_img_from', true );
						if ( $img_from && 'featured' == $img_from ) {
							if ( has_post_thumbnail() ) {
								$url = get_the_post_thumbnail_url( get_the_ID(), 'full' );
								$imgid = get_post_thumbnail_id();
							}
						} elseif ( 'upload' == $img_from ) {
							$upl_img = get_post_meta( $cid, 'dbacf_header_img_dbacf_upload_img', true );
							if ( ! empty( $upl_img ) ) {
								$url = wp_get_attachment_image_src( $upl_img, 'full' );
								$imgid = $upl_img;
							};
						}
						// Image position
						$bg_pos = get_post_meta( $cid, 'dbacf_header_img_dbacf_bg_position', true );
						if ( $bg_pos && 'x-y' == $bg_pos ) {
							$x_pos = get_post_meta( $cid, 'dbacf_header_img_dbacf_x_position', true );
							$y_pos = get_post_meta( $cid, 'dbacf_header_img_dbacf_y_position', true );
							$img_pos = $x_pos . '%' . ' ' . $y_pos . '%';
						} else {
							$img_pos = $bg_pos;
						}
						//Image filter
						$img_filter = get_post_meta( $cid, 'dbacf_header_img_dbacf_img_filter', true );
						if ( $img_filter && 'none' !== $img_filter ) {
							$img_filter_pc = get_post_meta( $cid, 'dbacf_header_img_dbacf_img_filter_percent', true );
							if ( $img_filter_pc ) {
								$img_filter_txt = $img_filter . '(' . $img_filter_pc . '%)';
							}
						}
						//Image background repeat
						$img_repeat = get_post_meta( $cid, 'dbacf_header_img_dbacf_bg_repeat', true );
						if ( empty( $img_repeat ) ) {
							$img_repeat = 'no-repeat';
						}
					}
					//Header
					$imgbgcolour = get_post_meta( $cid, 'dbacf_header_bg_colour', true );
					$img_width = get_post_meta( $cid, 'dbacf_header_width', true );
					if ( empty( $img_width ) ) {
						$img_width = 'full-width';
					}
					$img_ht = get_post_meta( $cid, 'dbacf_header_height', true );
					$mimg_ht = get_post_meta( $cid, 'dbacf_header_smldev_height', true );
					if ( ! $img_ht ) {
						$img_ht = 280;
					}
					//Titles
					$styles = '';
					$showheadertitle = get_post_meta( $cid, 'dbacf_show_title_on_header', true );
					$headertitlecolor = get_post_meta( $cid, 'dbacf_title_colour_on_header', true );
					$centertitle = get_post_meta( $cid, 'dbacf_center_title', true );
					if ( ! $centertitle ) {
						$hpos = get_post_meta( $cid, 'dbacf_horizontal_pos', true );
						if ( '' == $hpos ) {
							$hpos = 'left';
						}
						$vpos = get_post_meta( $cid, 'dbacf_vertical_pos', true );
						if ( '' == $vpos ) {
							$vpos = 'top';
						}
						$title_x = get_post_meta( $cid, 'dbacf_title_x', true );
						$title_y = get_post_meta( $cid, 'dbacf_title_y', true );
					}
					if ( $showheadertitle && true == $showheadertitle ) { // show title
						if ( ! $centertitle ) {
							$styles .= '.titlepos { position: absolute; ';
							$styles .= $hpos . ': ' . esc_attr( $title_x ) . 'px; ';
							$styles .= $vpos . ': ' . esc_attr( $title_y ) . 'px; }';
						} else {
							$styles .= '.titlepos { position: absolute; ';
							$styles .= 'top: 50%; left: 50%; transform: translate(-50%, -50%); }';
						}
						if ( ! empty( $headertitlecolor ) ) {
							$styles .= '.dba-img-title { color: ' . esc_attr( $headertitlecolor ) . '; }';
						}
					}
					// Subtitle
					$showsubtitle = get_post_meta( $cid, 'dbacf_show_subtitle', true );
					if ( $showsubtitle && true == $showsubtitle ) {
							$headersubtitle = get_post_meta( $cid, 'dbacf_header_subtitle', true );
							$showsubtitlefrom = get_post_meta( $cid, 'dbacf_header_subtitle_dbacf_show_subtitle_from', true );
							if ( $showsubtitlefrom ) {
								switch ( $showsubtitlefrom ) {
								case 'customtext':
									$subtitle = get_post_meta( $cid, 'dbacf_header_subtitle_dbacf_subtitle', true );
									break;
								case 'excerpt':
									if ( is_category() || is_tag() || is_author() ) {
										$subtitle = get_the_archive_description();
									} else {
										$subtitle = ( has_excerpt() ? get_the_excerpt() : '' );
									}
									break;
								case 'customfield':
									$customfieldname = get_post_meta( $cid, 'dbacf_header_subtitle_dbacf_subtitle_field_name', true );
									if ( $customfieldname ) {
										$subtitle = get_post_meta( $cid, $customfieldname, true );
									}
									break;
								}
							}
						if ( true == $showheadertitle ) { //show title & subtitle
							$styles .= '.subtitlepos { padding: 5px 10px 0 ; }';
						} elseif ( false == $showheadertitle ) { // show subtitle only
							if ( ! $centertitle ) {
								$styles .= '.subtitlepos { position: absolute; ';
								$styles .= $hpos . ': ' . esc_attr( $title_x ) . 'px; ';
								$styles .= $vpos . ': ' . esc_attr( $title_y ) . 'px; }';
							} else {
								$styles .= '.subtitlepos { position: absolute; ';
								$styles .= 'top: 50%; left: 50%; transform: translate(-50%, -50%); }';
							}
						}
						if ( ! empty( $headertitlecolor ) ) {
							$styles .= '.dba-img-subtitle { color: ' . esc_attr( $headertitlecolor ) . '; }';
						}
					}

					$styles .= '.dba-headerimg { position: relative; }';
					if ( 'img' == $headertype ) {
						$styles .= '.img-cover { ';
						$styles .= 'background-color: ' . esc_attr( $imgbgcolour ) . '; ';
						$styles .= 'background-size: ' . esc_attr( $img_size ) . '; ';
						$styles .= 'background-position: ' . esc_attr( $img_pos ) . '; ';
						$styles .= 'height: ' . esc_attr( $img_ht ) . 'px; ';
						$styles .= 'background-repeat: ' . esc_attr( $img_repeat ) . '; ';
						if ( $img_filter && 'none' !== $img_filter && $img_filter_pc ) {
							$styles .= 'filter: ' . esc_attr( $img_filter_txt ) . '; ';
							$styles .= '-webkit-filter: ' . esc_attr( $img_filter_txt ) . '; ';
						}
						$styles .= '}';
						$styles .= dfu_busacc_fn_get_reponsive_img_css( $imgid, '.img-cover' );
					} elseif ( 'bgcolour' == $headertype ) {
						$styles .= '.img-cover { ';
						$styles .= 'background-color: ' . esc_attr( $imgbgcolour ) . '; ';
						$styles .= 'height: ' . esc_attr( $img_ht ) . 'px; }';
					}
					$styles .= '@media screen and (max-width: 767px) { ';
					$styles .= '.img-cover { ';
					$styles .= 'height: ' . esc_attr( $mimg_ht ) . 'px; }';
					$styles .= '}';
					echo '<style type="text/css">';
					echo wp_kses_post( $styles );
					echo '</style>';

					if ( ( 'img' == $headertype && ! empty( $url ) ) || 'bgcolour' == $headertype ) {
					?>
						<section id="headerimg" class="dba-headerimg">
							<div class="<?php echo esc_attr( $img_width ); ?> px-0">
								<div class="row no-gutters">
									<div class="col">
										<div class="img-cover"></div><!-- img-cover -->
											<?php
											$titleonheader = get_post_meta( $cid, 'dbacf_title_style_on_header', true );
											if ( $titleonheader && 'none' == $titleonheader ) {
												$titleonheader = '';
											}
											if ( $titleonheader && 'default' == $titleonheader ) {
												$defaulttitlestyle = get_theme_mod( 'dba_default_title_style', 'none' );
												if ( 'none' == $defaulttitlestyle ) {
													$titleonheader = '';
												} else {
													$titleonheader = $defaulttitlestyle;
												}
											}
											if ( is_archive() ) {
												$title = get_the_archive_title();
											} elseif ( ! is_archive() ) {
												$title = get_the_title();
											}
											if ( $showheadertitle && true == $showheadertitle ) {
											?>
												<div class="titlepos"><h1 class="entry-title <?php echo esc_attr( $titleonheader ); ?> dba-img-title"><span><?php echo esc_html( $title ); ?></span></h1>
											<?php
											}
											if ( $showsubtitle && true == $showsubtitle ) {
											?>
												<h2 class="subtitlepos dba-img-subtitle"><?php echo wp_kses_post( $subtitle ); ?></h2>
											<?php
											}
											if ( $showheadertitle && true == $showheadertitle ) {
												echo '</div><!-- titlepos -->';
											}
											?>
									</div><!-- img-wrapper -->
								</div><!-- row -->
							</div><!-- container-fluid -->
						</section>
					<?php
					}
				} elseif ( $headertype && 'slider' == $headertype ) {
					$slider = get_post_meta( get_the_ID(), 'dbacf_slider', true );
					if ( $slider ) {
						$sliderwidth = $slider['dbacf_slider_width'];
						if ( $sliderwidth && 'full' == $sliderwidth ) {
						?>
							<section id="headerslider"><div class="container-fluid">
						<?php
						} elseif ( $sliderwidth && 'container' == $sliderwidth ) {
						?>
							<section id="headerslider"><div class="container">
						<?php
						}
						?>
								<div class="row">
									<?php
									$scode = $slider['dbacf_slider_shortcode'];
									if ( $scode ) {
										echo do_shortcode( esc_html( $scode ) );
									}
									?>
								</div><!-- row -->
							</div><!-- container-fluid -->
							</section>
					<?php
					}
				}
			} else {
				// taxonomy
				$cid = $term->term_id;
				$headertype = get_term_meta( $cid, 'dbacf_header_type', true );
				if ( $headertype && ( 'img' == $headertype || 'bgcolour' == $headertype ) ) {
					if ( 'img' == $headertype ) {
						$img_size = get_term_meta( $cid, 'dbacf_header_img_dbacf_bg_img_size', true );
						// Image location
						$img_from = get_term_meta( $cid, 'dbacf_header_img_dbacf_img_from', true );
						if ( $img_from && 'featured' == $img_from ) {
							if ( has_post_thumbnail() ) {
								$url = get_the_post_thumbnail_url( get_the_ID(), 'full' );
								$imgid = get_post_thumbnail_id();
							}
						} elseif ( 'upload' == $img_from ) {
							$upl_img = get_term_meta( $cid, 'dbacf_header_img_dbacf_upload_img', true );
							if ( ! empty( $upl_img ) ) {
								$url = wp_get_attachment_image_src( $upl_img, 'full' );
								$imgid = $upl_img;
							};
						}
						// Image position
						$bg_pos = get_term_meta( $cid, 'dbacf_header_img_dbacf_bg_position', true );
						if ( $bg_pos && 'x-y' == $bg_pos ) {
							$x_pos = get_term_meta( $cid, 'dbacf_header_img_dbacf_x_position', true );
							$y_pos = get_term_meta( $cid, 'dbacf_header_img_dbacf_y_position', true );
							$img_pos = $x_pos . '%' . ' ' . $y_pos . '%';
						} else {
							$img_pos = $bg_pos;
						}
						//Image filter
						$img_filter = get_term_meta( $cid, 'dbacf_header_img_dbacf_img_filter', true );
						if ( $img_filter && 'none' !== $img_filter ) {
							$img_filter_pc = get_term_meta( $cid, 'dbacf_header_img_dbacf_img_filter_percent', true );
							if ( $img_filter_pc ) {
								$img_filter_txt = $img_filter . '(' . $img_filter_pc . '%)';
							}
						}
						//Image background repeat
						$img_repeat = get_term_meta( $cid, 'dbacf_header_img_dbacf_bg_repeat', true );
						if ( empty( $img_repeat ) ) {
							$img_repeat = 'no-repeat';
						}
					}
					//Header
					$imgbgcolour = get_term_meta( $cid, 'dbacf_header_bg_colour', true );
					$img_width = get_term_meta( $cid, 'dbacf_header_width', true );
					if ( empty( $img_width ) ) {
						$img_width = 'full-width';
					}
					$img_ht = get_term_meta( $cid, 'dbacf_header_height', true );
					$mimg_ht = get_term_meta( $cid, 'dbacf_header_smldev_height', true );
					if ( ! $img_ht ) {
						$img_ht = 280;
					}
					//Titles
					$styles = '';
					$showheadertitle = get_term_meta( $cid, 'dbacf_show_title_on_header', true );
					$headertitlecolor = get_term_meta( $cid, 'dbacf_title_colour_on_header', true );
					$centertitle = get_term_meta( $cid, 'dbacf_center_title', true );
					if ( ! $centertitle ) {
						$hpos = get_term_meta( $cid, 'dbacf_horizontal_pos', true );
						if ( '' == $hpos ) {
							$hpos = 'left';
						}
						$vpos = get_term_meta( $cid, 'dbacf_vertical_pos', true );
						if ( '' == $vpos ) {
							$vpos = 'top';
						}
						$title_x = get_term_meta( $cid, 'dbacf_title_x', true );
						$title_y = get_term_meta( $cid, 'dbacf_title_y', true );
					}
					if ( $showheadertitle && true == $showheadertitle ) { // show title
						if ( ! $centertitle ) {
							$styles .= '.titlepos { position: absolute; ';
							$styles .= $hpos . ': ' . esc_attr( $title_x ) . 'px; ';
							$styles .= $vpos . ': ' . esc_attr( $title_y ) . 'px; }';
						} else {
							$styles .= '.titlepos { position: absolute; ';
							$styles .= 'top: 50%; left: 50%; transform: translate(-50%, -50%); }';
						}
						if ( ! empty( $headertitlecolor ) ) {
							$styles .= '.dba-img-title { color: ' . esc_attr( $headertitlecolor ) . '; }';
						}
					}
					// Subtitle
					$showsubtitle = get_term_meta( $cid, 'dbacf_show_subtitle', true );
					if ( $showsubtitle && true == $showsubtitle ) {
							$headersubtitle = get_term_meta( $cid, 'dbacf_header_subtitle', true );
							$showsubtitlefrom = get_term_meta( $cid, 'dbacf_header_subtitle_dbacf_show_subtitle_from', true );
							if ( $showsubtitlefrom ) {
								switch ( $showsubtitlefrom ) {
								case 'customtext':
									$subtitle = get_term_meta( $cid, 'dbacf_header_subtitle_dbacf_subtitle', true );
									break;
								case 'excerpt':
									if ( is_category() || is_tag() || is_author() ) {
										$subtitle = get_the_archive_description();
									} else {
										$subtitle = ( has_excerpt() ? get_the_excerpt() : '' );
									}
									break;
								case 'customfield':
									$customfieldname = get_term_meta( $cid, 'dbacf_header_subtitle_dbacf_subtitle_field_name', true );
									if ( $customfieldname ) {
										$subtitle = get_term_meta( $cid, $customfieldname, true );
									}
									break;
								}
							}
						if ( true == $showheadertitle ) { //show title & subtitle
							$styles .= '.subtitlepos { padding: 5px 10px 0 ; }';
						} elseif ( false == $showheadertitle ) { // show subtitle only
							if ( ! $centertitle ) {
								$styles .= '.subtitlepos { position: absolute; ';
								$styles .= $hpos . ': ' . esc_attr( $title_x ) . 'px; ';
								$styles .= $vpos . ': ' . esc_attr( $title_y ) . 'px; }';
							} else {
								$styles .= '.subtitlepos { position: absolute; ';
								$styles .= 'top: 50%; left: 50%; transform: translate(-50%, -50%); }';
							}
						}
						if ( ! empty( $headertitlecolor ) ) {
							$styles .= '.dba-img-subtitle { color: ' . esc_attr( $headertitlecolor ) . '; }';
						}
					}
	
					$styles .= '.dba-headerimg { position: relative; }';
					if ( 'img' == $headertype ) {
						$styles .= '.img-cover { ';
						$styles .= 'background-color: ' . esc_attr( $imgbgcolour ) . '; ';
						$styles .= 'background-size: ' . esc_attr( $img_size ) . '; ';
						$styles .= 'background-position: ' . esc_attr( $img_pos ) . '; ';
						$styles .= 'height: ' . esc_attr( $img_ht ) . 'px; ';
						$styles .= 'background-repeat: ' . esc_attr( $img_repeat ) . '; ';
						if ( $img_filter && 'none' !== $img_filter && $img_filter_pc ) {
							$styles .= 'filter: ' . esc_attr( $img_filter_txt ) . '; ';
							$styles .= '-webkit-filter: ' . esc_attr( $img_filter_txt ) . '; ';
						}
						$styles .= '}';
						$styles .= dfu_busacc_fn_get_reponsive_img_css( $imgid, '.img-cover' );
					} elseif ( 'bgcolour' == $headertype ) {
						$styles .= '.img-cover { ';
						$styles .= 'background-color: ' . esc_attr( $imgbgcolour ) . '; ';
						$styles .= 'height: ' . esc_attr( $img_ht ) . 'px; }';
					}
					$styles .= '@media screen and (max-width: 767px) { ';
					$styles .= '.img-cover { ';
					$styles .= 'height: ' . esc_attr( $mimg_ht ) . 'px; }';
					$styles .= '}';
					echo '<style type="text/css">';
					echo wp_kses_post( $styles );
					echo '</style>';
	
					if ( ( 'img' == $headertype && ! empty( $url ) ) || 'bgcolour' == $headertype ) {
					?>
						<section id="headerimg" class="dba-headerimg">
							<div class="<?php echo esc_attr( $img_width ); ?> px-0">
								<div class="row no-gutters">
									<div class="col">
										<div class="img-cover"></div><!-- img-cover -->
											<?php
											$titleonheader = get_term_meta( $cid, 'dbacf_title_style_on_header', true );
											if ( $titleonheader && 'none' == $titleonheader ) {
												$titleonheader = '';
											}
											if ( $titleonheader && 'default' == $titleonheader ) {
												$defaulttitlestyle = get_theme_mod( 'dba_default_title_style', 'none' );
												if ( 'none' == $defaulttitlestyle ) {
													$titleonheader = '';
												} else {
													$titleonheader = $defaulttitlestyle;
												}
											}
											if ( is_archive() ) {
												$title = get_the_archive_title();
											} elseif ( ! is_archive() ) {
												$title = get_the_title();
											}
											if ( $showheadertitle && true == $showheadertitle ) {
											?>
												<div class="titlepos"><h1 class="entry-title <?php echo esc_attr( $titleonheader ); ?> dba-img-title"><span><?php echo esc_html( $title ); ?></span></h1>
											<?php
											}
											if ( $showsubtitle && true == $showsubtitle ) {
											?>
												<h2 class="subtitlepos dba-img-subtitle"><?php echo wp_kses_post( $subtitle ); ?></h2>
											<?php
											}
											if ( $showheadertitle && true == $showheadertitle ) {
												echo '</div><!-- titlepos -->';
											}
											?>
									</div><!-- img-wrapper -->
								</div><!-- row -->
							</div><!-- container-fluid -->
						</section>
					<?php
					}
				} elseif ( $headertype && 'slider' == $headertype ) {
					$slider = get_term_meta( $cid, 'dbacf_slider', true );
					if ( $slider ) {
						$sliderwidth = $slider['dbacf_slider_width'];
						if ( $sliderwidth && 'full' == $sliderwidth ) {
						?>
							<section id="headerslider"><div class="container-fluid">
						<?php
						} elseif ( $sliderwidth && 'container' == $sliderwidth ) {
						?>
							<section id="headerslider"><div class="container">
						<?php
						}
						?>
								<div class="row">
									<?php
									$scode = $slider['dbacf_slider_shortcode'];
									if ( $scode ) {
										echo do_shortcode( esc_html( $scode ) );
									}
									?>
								</div><!-- row -->
							</div><!-- container-fluid -->
							</section>
					<?php
					}
				}
			}
		}
	}
}

/**
 * Get footer width
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_get_footer_width' ) ) {
	function dfu_busacc_fn_get_footer_width() {
		$fwidth = get_theme_mod( 'dba_footer_width' );
		if ( is_post_type_archive() || ( is_home() && ! is_front_page() ) ) {
			$achiveposttype = get_post_type();
			if ( is_home() ) { // handle case when no post is on site and get_post_type() returns 'page'
				$achiveposttype = 'post';
			} 
			if ( class_exists( 'woocommerce' ) ) {
				if ( is_archive() && ( is_product_category() || is_product_tag() || is_shop() ) ) {
					$achiveposttype = '';
				}
			}
			if ( '' != $achiveposttype && class_exists( 'DFU_Busacc_Addon' ) ) {
				if ( post_type_exists( 'post_types_info' ) ) {
					$ptiargs = array(
						'post_type'        => 'post_types_info',
						'posts_per_page'   => 1,
						'post_status'      => 'publish',
						'meta_key'         => 'dbacf_ptype',
						'meta_value'       => $achiveposttype,
						'order'            => 'DESC',
						'orderby'          => 'date',
					);
					$ptiquery = new WP_Query( $ptiargs );
					if ( $ptiquery->have_posts() ) {
						while ( $ptiquery->have_posts() ) {
							$ptiquery->the_post();
							$fwidth = dfu_busacc_fn_get_footer_width_class();
						}
						wp_reset_postdata();
					}
				}
			} else {
				$fwidth = dfu_busacc_fn_get_footer_width_class();
			}
		} elseif ( is_category() || is_tag() || is_tax() ) {
			$term = get_queried_object();
			$fwidth = dfu_busacc_fn_get_footer_width_class( $term );
		} else {
			$fwidth = dfu_busacc_fn_get_footer_width_class();
		}
		return $fwidth;
	}
}

if ( ! function_exists( 'dfu_busacc_fn_get_footer_width_class' ) ) {
	function dfu_busacc_fn_get_footer_width_class( $term = '' ) {
		$fwidth = '';
		if ( function_exists( 'get_field' ) ) {
			$fwidth = get_field( 'dbacf_footer_width', $term );
		} else { // ACF not available
			if ( empty( $term ) ) {
				$term = get_the_ID();
			}
			$fwidth = get_post_meta( $term, 'dbacf_footer_width', true );
		}
		if ( '' == $fwidth ) {
			$fwidth = get_theme_mod( 'dba_footer_width', 'container' );
		}
		return $fwidth;
	}
}

/**
 * Add sections (section is added on front page one at a time)
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_add_sections' ) ) {
	function dfu_busacc_fn_add_sections( $sectid, $term = '' ) {
		if ( function_exists( 'have_rows' ) ) {
			if ( have_rows( 'dbacf_sections', $term ) ) :
			?>
				<div class="dba-section">
					<?php
					$i = 0;
					while ( have_rows( 'dbacf_sections', $term ) ) :
						the_row();
						$sectname = get_sub_field( 'dbacf_sect_name' );
						if ( empty( $sectid ) || 'sect-' . $sectname == $sectid ) {
							$bg = get_sub_field( 'dbacf_bg_colour_or_img' );
							$txtalign = get_sub_field( 'dbacf_text_align' );
							$headcolor = get_sub_field( 'dbacf_head_colour' );
							$txtcolor = get_sub_field( 'dbacf_text_colour' );
							$bgcolor = get_sub_field( 'dbacf_section_bgcolour' );
							$grad1 = get_sub_field( 'dbacf_gradient_bgcolour_1' );
							$grad2 = get_sub_field( 'dbacf_gradient_bgcolour_2' );
							$gradopacity = get_sub_field( 'dbacf_bg_gradient_opacity' );
							$graddir = get_sub_field( 'dbacf_bg_gradient_direction' );
							if ( ! empty( $grad1 ) ) {
								$gradientrgb1 = dfu_busacc_fn_hex2rgb( $grad1 );
								$rgba1 = 'rgba(' . esc_attr( $gradientrgb1['r'] ) . ',' . esc_attr( $gradientrgb1['g'] ) . ',' . esc_attr( $gradientrgb1['b'] ) . ', ' . ( ! empty( $gradopacity ) ? esc_attr( $gradopacity ) : '0.7' ) . ')';
							}
							if ( ! empty( $grad2 ) ) {
								$gradientrgb2 = dfu_busacc_fn_hex2rgb( $grad2 );
								$rgba2 = 'rgba(' . esc_attr( $gradientrgb2['r'] ) . ',' . esc_attr( $gradientrgb2['g'] ) . ',' . esc_attr( $gradientrgb2['b'] ) . ', ' . ( ! empty( $gradopacity ) ? esc_attr( $gradopacity ) : '0.7' ) . ')';
							}
							if ( empty( $headcolor ) ) {
								$headcolor = get_theme_mod( 'dba_h2_font["color"]', '#28292a' );
							}
							if ( empty( $txtcolor ) ) {
								$txtcolor = get_theme_mod( 'dba_default_font["color"]', '#28292a' );
							}
							$style = 'color:' . esc_attr( $txtcolor ) . ';' . ( ! empty( $bgcolor ) ? 'background-color:' . esc_attr( $bgcolor ) . ';' : '' );
							if ( 'colour' == $bg ) {
								$style .= 'background:linear-gradient(' . ( ! empty( $graddir ) ? esc_attr( $graddir ) : 'to right bottom' ) . ', ' . $rgba1 . ',' . $rgba2 . '); ';
							}
							if ( 'img' == $bg ) {
								$bgimg = get_sub_field( 'dbacf_section_bgimg' );
								if ( ! empty( $bgimg ) ) {
									$bgimgsize = get_sub_field( 'dbacf_background_size' );
									$bgimgpos = get_sub_field( 'dbacf_background_position' );
									$bgimgrep = get_sub_field( 'dbacf_background_repeat' );
								}
								if ( ! empty( $grad1 ) && ! empty( $grad2 ) ) {
									$grad = 'linear-gradient(' . ( ! empty( $graddir ) ? esc_attr( $graddir ) : 'to right bottom' ) . ', ' . $rgba1 . ',' . $rgba2 . ')';
								} else {
									$grad = '';
								}
								dfu_busacc_fn_bgimg_css( '.dba-sect-' . esc_attr( $sectname ), ( ! empty( $bgimg ) ? attachment_url_to_postid( $bgimg ) : '' ), $grad, $bgimgpos, $bgimgsize, $bgimgrep, '', '', true, true );
							}
							global $post;
							$post_slug = $post->post_name;
							?>

							<div class="py-5 <?php echo esc_attr( $txtalign ); ?> <?php echo 'dba-sect-' . esc_attr( $sectname ); ?>" id="sect-<?php echo 'page-' . esc_attr( $post_slug ) . '-' . esc_attr( $sectname ); ?>" style="<?php echo $style; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>">
								<div class="<?php echo esc_attr( get_sub_field( 'dbacf_section_content_width' ) ); ?>">
									<?php
									$cstyle = '';
									$contentstyle = '';
									$contentstylemed = '';
									$contentstylelge = '';
									$contentimg = '';
									$sectionhead = get_sub_field( 'dbacf_section_head' );
									$headlink = get_sub_field( 'dbacf_heading_link' );
									$linktext = get_sub_field( 'dbacf_link_text' );
									$contentbgcolor = get_sub_field( 'dbacf_content_bgcolour' );
									$contentbgbgopacity = get_sub_field( 'dbacf_content_bg_opacity' );
									$contentgraddeg = get_sub_field( 'dbacf_content_gradient_degree' );
									$contentperc = get_sub_field( 'dbacf_content_perc' );
									$contentpad = get_sub_field( 'dbacf_content_padding' );
									$medperc = 100 - ( 100 - $contentperc ) / 2;
									$contentimg = get_sub_field( 'dbacf_content_bgimg' );
									if ( ! empty( $contentimg ) ) {
										$cbgimgsize = get_sub_field( 'dbacf_content_bg_size' );
										$cbgimgpos = get_sub_field( 'dbacf_content_bg_pos' );
										$cbgimgrep = get_sub_field( 'dbacf_content_bg_repeat' );
										$imgid = attachment_url_to_postid( $contentimg );
										$bgimgurl = dfu_busacc_fn_get_responsive_img_url( $imgid );
										$cstyle .= 'background-repeat:' . esc_attr( $cbgimgrep ) . ';';
										$cstyle .= 'background-size:' . esc_attr( $cbgimgsize ) . ';';
										$cstyle .= 'background-position:' . esc_attr( $cbgimgpos ) . ';';
									}
									if ( ! empty( $contentbgcolor ) || ! empty( $contentimg ) ) {
										$containerbgcolorrgb = dfu_busacc_fn_hex2rgb( $contentbgcolor );
										$containerbgcolorrgba = 'rgba(' . esc_attr( $containerbgcolorrgb['r'] ) . ',' . esc_attr( $containerbgcolorrgb['g'] ) . ',' . esc_attr( $containerbgcolorrgb['b'] ) . ', ' . esc_attr( $contentbgbgopacity ) . ')';
										if ( ! empty( $contentgraddeg ) || ! empty( $contentperc ) ) {
											$contentstylexs = 'background:linear-gradient(' . esc_attr( $contentgraddeg ) . 'deg,' . $containerbgcolorrgba . ' 0%,' . $containerbgcolorrgba . ' 100%, transparent ' . ' 100%)' . ( ! empty( $contentimg ) ? ', url(' . esc_url( $bgimgurl['xs'] ) . ')' : '' ) . '; ';
											$contentstylesm = 'background:linear-gradient(' . esc_attr( $contentgraddeg ) . 'deg,' . $containerbgcolorrgba . ' 0%,' . $containerbgcolorrgba . ' 100%, transparent ' . ' 100%)' . ( ! empty( $contentimg ) ? ', url(' . esc_url( $bgimgurl['sm'] ) . ')' : '' ) . '; ';
											$contentstylemd = 'background:linear-gradient(' . esc_attr( $contentgraddeg ) . 'deg,' . $containerbgcolorrgba . ' 0%,' . $containerbgcolorrgba . ' ' . esc_attr( $medperc ) . '%, transparent ' . esc_attr( $medperc ) . '%)' . ( ! empty( $contentimg ) ? ', url(' . esc_url( $bgimgurl['md'] ) . ')' : '' ) . '; ';
											$contentstylelg = 'background:linear-gradient(' . esc_attr( $contentgraddeg ) . 'deg,' . $containerbgcolorrgba . ' 0%,' . $containerbgcolorrgba . ' ' . esc_attr( $contentperc ) . '%, transparent ' . esc_attr( $contentperc ) . '%)' . ( ! empty( $contentimg ) ? ', url(' . esc_url( $bgimgurl['lg'] ) . ')' : '' ) . '; ';
											$contentstylefull = 'background:linear-gradient(' . esc_attr( $contentgraddeg ) . 'deg,' . $containerbgcolorrgba . ' 0%,' . $containerbgcolorrgba . ' ' . esc_attr( $contentperc ) . '%, transparent ' . esc_attr( $contentperc ) . '%)' . ( ! empty( $contentimg ) ? ', url(' . esc_url( $bgimgurl['full'] ) . ')' : '' ) . '; ';
										} else {
											$contentstyle = 'background:' . $containerbgcolorrgba . ( ! empty( $contentimg ) ? ', url(' . $contentimg . ')' : '' ) . '; ';
										}
									} else {
										$contentstyle = 'background:' . $contentbgcolor . '; ';
									}
									echo '<style type="text/css">';
									echo '.dba-cont-bg.' . esc_attr( $sectname ) . ' {' . esc_attr( $contentstylexs ) . '}';
									echo '.dba-sect-content.' . esc_attr( $sectname ) . ' {width:100%} ';
									echo '@media (min-width:576px) {';
									echo '.dba-cont-bg.' . esc_attr( $sectname ) . ' {' . esc_attr( $contentstylesm ) . '}';
									echo '.dba-sect-content.' . esc_attr( $sectname ) . ' {width:100%} ';
									echo '} ';
									echo '@media (min-width:768px) {';
									echo '.dba-cont-bg.' . esc_attr( $sectname ) . ' {' . esc_attr( $contentstylemd ) . '}';
									echo '.dba-sect-content.' . esc_attr( $sectname ) . ' {width:' . esc_attr( $medperc ) . '%;' . ( ! empty( $contentpad ) ? 'padding:' . esc_attr( $contentpad ) . 'rem;' : '' ) . '}';
									echo '} ';
									echo '@media (min-width:992px) {';
									echo '.dba-cont-bg.' . esc_attr( $sectname ) . ' {' . esc_attr( $contentstylelg ) . '}';
									echo '.dba-sect-content.' . esc_attr( $sectname ) . '  {width:' . esc_attr( $contentperc ) . '%;' . ( ! empty( $contentpad ) ? 'padding:' . esc_attr( $contentpad ) . 'rem;' : '' ) . '}';
									echo '}';
									echo '@media (min-width:1200px) {';
									echo '.dba-cont-bg.' . esc_attr( $sectname ) . ' {' . esc_attr( $contentstylefull ) . '}';
									echo '.dba-sect-content.' . esc_attr( $sectname ) . '  {width:' . esc_attr( $contentperc ) . '%;' . ( ! empty( $contentpad ) ? 'padding:' . esc_attr( $contentpad ) . 'rem;' : '' ) . '}';
									echo '}';
									echo '</style>';
									?>

									<div class="py-4 px-4 dba-cont-bg <?php echo esc_attr( $sectname ); ?>" <?php echo ( ! empty( $cstyle ) ? 'style="' . $cstyle . '"' : '' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>>
										<?php
										do_action( 'dfu_busacc_a_b4_sectcontent_' . 'page_' . $post_slug . '_' . $sectname );
										$titlestyle = get_theme_mod( 'dba_default_head_style' );
										?>
										<div class="dba-sect-content <?php echo esc_attr( $sectname ); ?>">
										<h2 class="section-title <?php echo esc_attr( $titlestyle ); ?>" style="color: <?php echo esc_attr( $headcolor ); ?>;" >
										<?php
										echo esc_html( $sectionhead );
										?>
										<?php
										if ( ! empty( $headlink ) ) {
										?>
											<a class="small" href="<?php echo esc_url( $headlink ); ?>"><?php echo ( ! empty( $linktext ) ? esc_html( $linktext ) : esc_html__( 'view all', 'dfu-busacc' ) ); ?></a>
										<?php
										}
										?>
										</h2>
										<?php
										the_sub_field( 'dbacf_section_content' );
										do_action( 'dfu_busacc_a_aft_sectcontent_' . 'page_' . $post_slug . '_' . $sectname );
										$i++;
										?>
										</div><!-- .dba-sect-content -->
									</div>
								</div><!-- container -->
							</div><!-- row -->
						<?php
						}
					endwhile;
					?>
				</div><!-- dba-section -->
			<?php
			return $bgcolor;
			endif;
		} else {
			$sects = get_post_meta( get_the_ID(), 'dbacf_sections', true );
			if ( $sects ) :
			?>
				<div class="dba-section">
					<?php
					for ( $i = 0; $i < $sects; $i++ ) {
						$sectname = esc_html( get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_sect_name', true ) );
						if ( empty( $sectid ) || 'sect-' . $sectname == $sectid ) {
							$bg = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_bg_colour_or_img', true );
							$txtalign = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_text_align', true );
							$headcolor = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_head_colour', true );
							$txtcolor = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_text_colour', true );
							$bgcolor = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_section_bgcolour', true );
							$grad1 = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_gradient_bgcolour_1', true );
							$grad2 = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_gradient_bgcolour_2', true );
							$gradopacity = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_bg_gradient_opacity', true );
							$graddir = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_bg_gradient_direction', true );
							if ( ! empty( $grad1 ) ) {
								$gradientrgb1 = dfu_busacc_fn_hex2rgb( $grad1 );
								$rgba1 = 'rgba(' . $gradientrgb1['r'] . ',' . $gradientrgb1['g'] . ',' . $gradientrgb1['b'] . ', ' . ( ! empty( $gradopacity ) ? $gradopacity : '0.7' ) . ')';
							}
							if ( ! empty( $grad2 ) ) {
								$gradientrgb2 = dfu_busacc_fn_hex2rgb( $grad2 );
								$rgba2 = 'rgba(' . $gradientrgb2['r'] . ',' . $gradientrgb2['g'] . ',' . $gradientrgb2['b'] . ', ' . ( ! empty( $gradopacity ) ? $gradopacity : '0.7' ) . ')';
							}
							if ( empty( $headcolor ) ) {
								$headcolor = get_theme_mod( 'dba_h2_font["color"]', '#28292a' );
							}
							if ( empty( $txtcolor ) ) {
								$txtcolor = get_theme_mod( 'dba_default_font["color"]', '#28292a' );
							}
							$style = 'color:' . esc_attr( $txtcolor ) . ';' . ( ! empty( $bgcolor ) ? 'background-color:' . esc_attr( $bgcolor ) . ';' : '' );
							if ( 'colour' == $bg ) {
								$style .= 'background:linear-gradient(' . ( ! empty( $graddir ) ? $graddir : 'to right bottom' ) . ', ' . $rgba1 . ',' . $rgba2 . '); ';
							}
							if ( 'img' == $bg ) {
								$bgimg = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_section_bgimg', true );
								if ( ! empty( $bgimg ) ) {
									$bgimgattr = wp_get_attachment_image_src( $bgimg, 'full' );
									$bgimgsize = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_background_size', true );
									$bgimgpos = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_background_position', true );
									$bgimgrep = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_background_repeat', true );

								}
								if ( ! empty( $grad1 ) && ! empty( $grad2 ) ) {
									$grad = 'linear-gradient(' . ( ! empty( $graddir ) ? esc_attr( $graddir ) : 'to right bottom' ) . ', ' . $rgba1 . ',' . $rgba2 . ')';
								} else {
									$grad = '';
								}
								dfu_busacc_fn_bgimg_css( '.dba-sect-' . esc_attr( $sectname ), ( ! empty( $bgimg ) ? $bgimg : '' ), $grad, $bgimgpos, $bgimgsize, $bgimgrep, '', '', true, true );
							}
							global $post;
							$post_slug = $post->post_name;
							?>

							<div class="py-5 <?php echo esc_attr( $txtalign ); ?> <?php echo 'dba-sect-' . esc_attr( $sectname ); ?>" id="sect-<?php echo 'page-' . esc_attr( $post_slug ) . '-' . esc_attr( $sectname ); ?>" style="<?php echo esc_html( $style ); ?>">
								<div class="<?php echo esc_attr( get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_section_content_width', true ) ); ?>">
									<?php
									$cstyle = '';
									$contentstyle = '';
									$contentstylemed = '';
									$contentstylelge = '';
									$contentimg = '';
									$sectionhead = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_section_head', true );
									$headlink = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_heading_link', true );
									$linktext = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_link_text', true );
									$contentbgcolor = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_content_bgcolour', true );
									$contentbgbgopacity = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_content_bg_opacity', true );
									$contentgraddeg = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_content_gradient_degree', true );
									$contentperc = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_content_perc', true );
									$contentpad = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_content_padding', true );
									$medperc = 100 - ( 100 - $contentperc ) / 2;
									$contentimg = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_content_bgimg', true );
									if ( ! empty( $contentimg ) ) {
										$cbgimgattr = wp_get_attachment_image_src( $contentimg, 'full' );
										$cbgimgsize = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_content_bg_size', true );
										$cbgimgpos = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_content_bg_pos', true );
										$cbgimgrep = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_content_bg_repeat', true );

										$imgid = attachment_url_to_postid( $cbgimgattr[0] );
										$bgimgurl = dfu_busacc_fn_get_responsive_img_url( $imgid );

										$cstyle .= 'background-repeat:' . esc_attr( $cbgimgrep ) . ';';
										$cstyle .= 'background-size:' . esc_attr( $cbgimgsize ) . ';';
										$cstyle .= 'background-position:' . esc_attr( $cbgimgpos ) . ';';
									}
									if ( ! empty( $contentbgcolor ) || ! empty( $contentimg ) ) {
										$containerbgcolorrgb = dfu_busacc_fn_hex2rgb( $contentbgcolor );
										$containerbgcolorrgba = 'rgba(' . esc_attr( $containerbgcolorrgb['r'] ) . ',' . esc_attr( $containerbgcolorrgb['g'] ) . ',' . esc_attr( $containerbgcolorrgb['b'] ) . ', ' . esc_attr( $contentbgbgopacity ) . ')';
										if ( ! empty( $contentgraddeg ) || ! empty( $contentperc ) ) {
											$contentstylexs = 'background:linear-gradient(' . esc_attr( $contentgraddeg ) . 'deg,' . $containerbgcolorrgba . ' 0%,' . $containerbgcolorrgba . ' 100%, transparent' . ' 100%)' . ( ! empty( $contentimg ) ? ', url(' . esc_url( $bgimgurl['xs'] ) . ')' : '' ) . '; ';
											$contentstylesm = 'background:linear-gradient(' . esc_attr( $contentgraddeg ) . 'deg,' . $containerbgcolorrgba . ' 0%,' . $containerbgcolorrgba . ' 100%, transparent' . ' 100%)' . ( ! empty( $contentimg ) ? ', url(' . esc_url( $bgimgurl['sm'] ) . ')' : '' ) . '; ';
											$contentstylemd = 'background:linear-gradient(' . esc_attr( $contentgraddeg ) . 'deg,' . $containerbgcolorrgba . ' 0%,' . $containerbgcolorrgba . ' ' . esc_attr( $medperc ) . '%, transparent ' . esc_attr( $medperc ) . '%)' . ( ! empty( $contentimg ) ? ', url(' . esc_url( $bgimgurl['md'] ) . ')' : '' ) . '; ';
											$contentstylelg = 'background:linear-gradient(' . esc_attr( $contentgraddeg ) . 'deg,' . $containerbgcolorrgba . ' 0%,' . $containerbgcolorrgba . ' ' . esc_attr( $contentperc ) . '%, transparent ' . esc_attr( $contentperc ) . '%)' . ( ! empty( $contentimg ) ? ', url(' . esc_url( $bgimgurl['lg'] ) . ')' : '' ) . '; ';
											$contentstylefull = 'background:linear-gradient(' . esc_attr( $contentgraddeg ) . 'deg,' . $containerbgcolorrgba . ' 0%,' . $containerbgcolorrgba . ' ' . esc_attr( $contentperc ) . '%, transparent ' . esc_attr( $contentperc ) . '%)' . ( ! empty( $contentimg ) ? ', url(' . esc_url( $bgimgurl['full'] ) . ')' : '' ) . '; ';
										} else {
											$contentstyle = 'background:' . $containerbgcolorrgba . ( ! empty( $contentimg ) ? ', url(' . esc_url( $cbgimgattr[0] ) . ')' : '' ) . '; ';
										}
									} else {
										$contentstyle = 'background:' . esc_attr( $contentbgcolor ) . '; ';
									}
									echo '<style type="text/css">';
									echo '.dba-cont-bg.' . esc_attr( $sectname ) . ' {' . esc_attr( $contentstylexs ) . '}';
									echo '.dba-sect-content.' . esc_attr( $sectname ) . ' {width:100%} ';
									echo '@media screen and (min-width: 576px) {';
									echo '.dba-cont-bg.' . esc_attr( $sectname ) . ' {' . esc_attr( $contentstylesm ) . '}';
									echo '.dba-sect-content.' . esc_attr( $sectname ) . ' {width:100%} ';
									echo '} ';
									echo '@media screen and (min-width: 768px) {';
									echo '.dba-cont-bg.' . esc_attr( $sectname ) . ' {' . esc_attr( $contentstylemd ) . '}';
									echo '.dba-sect-content.' . esc_attr( $sectname ) . ' {width:' . esc_attr( $medperc ) . '%;' . ( ! empty( $contentpad ) ? 'padding:' . esc_attr( $contentpad ) . 'rem;' : '' ) . '}';
									echo '} ';
									echo '@media screen and (min-width:992px) {';
									echo '.dba-cont-bg.' . esc_attr( $sectname ) . ' {' . esc_attr( $contentstylelg ) . '}';
									echo '.dba-sect-content.' . esc_attr( $sectname ) . '  {width:' . esc_attr( $contentperc ) . '%;' . ( ! empty( $contentpad ) ? 'padding:' . esc_attr( $contentpad ) . 'rem;' : '' ) . '}';
									echo '}';
									echo '@media screen and (min-width: 1200px) {';
									echo '.dba-cont-bg.' . esc_attr( $sectname ) . ' {' . esc_attr( $contentstylefull ) . '}';
									echo '.dba-sect-content.' . esc_attr( $sectname ) . '  {width:' . esc_attr( $contentperc ) . '%;' . ( ! empty( $contentpad ) ? 'padding:' . esc_attr( $contentpad ) . 'rem;' : '' ) . '}';
									echo '}';
									echo '</style>';
									?>

									<div class="py-4 px-4 dba-cont-bg <?php echo esc_attr( $sectname ); ?>" <?php echo ( ! empty( $cstyle ) ? 'style="' . $cstyle . '"' : '' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>>
										<?php do_action( 'dfu_busacc_a_b4_sectcontent_' . 'page_' . $post_slug . '_' . $sectname ); ?>
										<div class="dba-sect-content <?php echo esc_attr( $sectname ); ?>">
										<h2 style="color: <?php echo esc_attr( $headcolor ); ?>;" ><?php echo esc_html( $sectionhead ); ?>
										<?php if ( ! empty( $headlink ) ) { ?>
											<a class="small" href="<?php echo esc_url( $headlink ); ?>"><?php echo ( ! empty( $linktext ) ? esc_html( $linktext ) : esc_html__( 'view all', 'dfu-busacc' ) ); ?></a>
										<?php
										}
										?>
										</h2>
										<?php
										$sectioncontent = get_post_meta( get_the_ID(), 'dbacf_sections_' . $i . '_dbacf_section_content', true );
										echo wp_kses_post( $sectioncontent );
										do_action( 'dfu_busacc_a_aft_sectcontent_' . 'page_' . $post_slug . '_' . $sectname );
										?>
										</div><!-- .dba-sect-content -->
									</div>
								</div><!-- container -->
							</div><!-- row -->
						<?php
						}
					}
					?>
				</div><!-- dba-section -->
			<?php
			return $bgcolor;
			endif;
		}
	}
}
if ( class_exists( 'DFU_Busacc_Addon' ) ) {
	add_action( 'dfu_busacc_a_after_content', 'dfu_busacc_fn_add_sections', 11 );
}

/**
 * Bootstrap pagination function
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_bs_paging' ) ) {
	function dfu_busacc_fn_bs_paging( $pages = '', $range = 1 ) {
		$showitems = ( $range * 2 ) + 1;
		$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
		if ( '' == $pages ) {
			global $wp_query;
			$pages = $wp_query->max_num_pages;
			if ( ! $pages ) {
				$pages = 1;
			}
		}
		if ( 1 != $pages ) {
			echo '<div class="row"><div class="col-12">';
			echo '<nav aria-label="page navigation">';
			echo '<ul class="pagination justify-content-center">';
			echo '<li class="page-item disabled d-none d-sm-block">';
			echo '<a class="page-link" href="#" tabindex="-1">Page ' . esc_html( ( empty( $paged ) ? '1' : $paged ) ) . ' of ' . esc_html( $pages );
			echo '</a></li>';
			if ( $paged > 2 && $paged > $range + 1 && $showitems < $pages ) {
				echo '<li class="page-item">';
				echo '<a class="page-link" href="' . esc_url( get_pagenum_link( 1 ) ) . '" aria-label="' . esc_attr( 'First page', 'dfu-busacc' ) . '">';
				echo '<span aria-hidden="true">&laquo;</span>';
				echo '<span class="sr-only">' . esc_html__( 'First page', 'dfu-busacc' ) . '</span>';
				echo '</a></li>';
			}
			if ( $paged > 1 && $showitems < $pages ) {
				echo '<li class="page-item">';
				echo '<a class="page-link" href="' . esc_url( get_pagenum_link( $paged - 1 ) ) . '" aria-label="' . esc_attr( 'Previous page', 'dfu-busacc' ) . '">';
				echo '<span aria-hidden="true">&lsaquo;</span>';
				echo '<span class="sr-only">' . esc_attr__( 'Previous page', 'dfu-busacc' ) . '</span>';
				echo '</a></li>';
			}
			for ( $i = 1; $i <= $pages; $i++ ) {
				if ( 1 != $pages && ( ! ( $i >= $paged + $range + 1 || $i <= $paged - $range - 1 ) || $pages <= $showitems ) ) {
					if ( $paged == $i || ( empty( $paged ) && 1 == $i ) ) {
						echo '<li class="page-item active">';
						echo '<a class="page-link" href="#" tabindex="-1"  aria-label="' . esc_attr( 'Current page', 'dfu-busacc' ) . '">';
						echo '<span>' . esc_attr( $i ) . '</span>';
						echo '<span class="sr-only">' . esc_html__( 'Current page', 'dfu-busacc' ) . '</span>';
						echo '</a></li>';
					} else {
						echo '<li class="page-item">';
						echo '<a class="page-link" href="' . esc_url( get_pagenum_link( $i ) ) . '">';
						echo '<span>' . esc_attr( $i ) . '</span>';
						echo '</a></li>';
					}
				}
			}
			if ( $paged < $pages && $showitems < $pages ) {
				echo '<li class="page-item">';
				echo '<a class="page-link" href="' . esc_url( get_pagenum_link( $paged + 1 ) ) . '" aria-label="' . esc_attr( 'Next page', 'dfu-busacc' ) . '">';
				echo '<span aria-hidden="true">&rsaquo;</span>';
				echo '<span class="sr-only">' . esc_html__( 'Next page', 'dfu-busacc' ) . '</span>';
				echo '</a></li>';
			}
			if ( $paged < $pages - 1 && $paged + $range - 1 < $pages && $showitems < $pages ) {
				echo '<li class="page-item">';
				echo '<a class="page-link" href="' . esc_url( get_pagenum_link( $pages ) ) . '" aria-label="' . esc_attr( 'Last page', 'dfu-busacc' ) . '">';
				echo '<span aria-hidden="true">&raquo;</span>';
				echo '<span class="sr-only">' . esc_html__( 'Last page', 'dfu-busacc' ) . '</span>';
				echo '</a></li>';
			}
			echo '</ul></nav>';
			echo '</div></div>';
		}
	}
}

/**
 * Page divider
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_display_divider' ) ) {
	function dfu_busacc_fn_display_divider( $id, $dstyle, $top, $btm ) {
		if ( ! empty( $dstyle ) && 'none' != $dstyle ) {
		?>
			<div id="divider-<?php echo esc_attr( $id ); ?>" style="overflow: hidden;<?php echo ( ! empty( $btm ) ? ' background-color:' . esc_attr( $btm ) . ';' : '' ); ?>">
				<div class="<?php echo esc_attr( $dstyle ); ?>" style="<?php echo ( ! empty( $top ) ? 'border-top-color:' . esc_attr( $top ) . ';' : '' ); ?>"></div>
			</div>
		<?php
		}
	}
}

/**
 * Get Icon effect display - FontAwesome
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_get_layer_icon_display' ) ) {
	function dfu_busacc_fn_get_layer_icon_display( $icostyle, $icon ) {
		if ( $icostyle ) :
			if ( 'default' == $icostyle ) {
				$icostyle = get_theme_mod( 'dba_default_ico_style' );
				if ( empty( $icostyle ) ) {
					$icostyle = 'none';
				}
			}
			if ( 'none' == $icostyle ) {
				$dispstr = '<i class="dba-toplayer ' . ' ' . esc_attr( $icon ) . '"></i>';
			} else {
				if ( substr( $icostyle, 0, 3 ) === 'fas' ) {
					$dispstr = '<span class="fa-layers fa-fw"><i class="' . $icostyle . '"></i><i class="dba-toplayer fa-inverse' . ' ' . esc_attr( $icon ) . '" data-fa-transform="shrink-11"></i></span>';
				} else {
					$dispstr = '<span class="fa-layers fa-fw"><i class="' . $icostyle . '"></i><i class="dba-toplayer' . ' ' . esc_attr( $icon ) . '" data-fa-transform="shrink-11"></i></span>';
				}
			}
		endif;
		return $dispstr;
	}
}

/**
 * Prints HTML with meta information for the current post-date/time and author.
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_blog_header' ) ) {
	function dfu_busacc_fn_blog_header() {
		if ( function_exists( 'get_field' ) ) {
			$showpostdate = get_field( 'dbacf_post_show_date' );
			$showauthor = get_field( 'dbacf_post_show_author' );
		} else {
			$showpostdate = get_post_meta( get_the_ID(), 'dbacf_post_show_date', true );
			$showauthor = get_post_meta( get_the_ID(), 'dbacf_post_show_author', true );
		}
		$showheadicon = get_theme_mod( 'dba_blog_show_header_ico' );
		$datetouse = get_theme_mod( 'dba_blog_date_to_use', 'update' );
		if ( 'update' == $datetouse ) {
			$time_string = '<time class="entry-date published updated" datetime="%1$s" itemprop="dateModified">%2$s</time><meta itemprop="datePublished" content="%3$s">';
			$time_string = sprintf(
				$time_string,
				esc_attr( get_the_modified_date( DATE_W3C ) ),
				esc_html( get_the_modified_date() ),
				esc_attr( get_the_date( DATE_W3C ) )
			);
		} else {
			$time_string = '<time class="entry-date published" datetime="%1$s" itemprop="datePublished">%2$s</time>';
			$time_string = sprintf(
				$time_string,
				esc_attr( get_the_date( DATE_W3C ) ),
				esc_html( get_the_date() )
			);
		}

		if ( $showpostdate ) {
			$postontitle = ( 'update' == $datetouse ? esc_html__( 'Last updated', 'dfu-busacc' ) : esc_html__( 'Created', 'dfu-busacc' ) );
			$posted_on = sprintf(
				/* translators: %s: post date. */
				$postontitle . esc_html_x( ' on %s', 'post date', 'dfu-busacc' ),
				'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
			);
			if ( $showheadicon && true == $showheadicon ) {
				if ( true == get_theme_mod( 'dba_load_fa', true ) ) {
					$postedonicon = apply_filters( 'dfu_busacc_f_postedon_faicon', '<i class="fas fa-calendar-day fa-fw" aria-hidden="true"></i>' );
					$posted_on = '<span class="dba-bloghead-ico">' . wp_kses_post( $postedonicon ) .'&nbsp;</span>' . $posted_on;
				} else {
					$postedonicon = apply_filters( 'dfu_busacc_f_postedon_icon', '<span class="iconmoon-dk ico-calendar"></span>' );
					$posted_on = '<span class="dba-bloghead-ico">' . wp_kses_post( $postedonicon ) . '&nbsp;</span>' . $posted_on;
				}
			}
			echo '<span class="posted-on">' . $posted_on . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}

		if ( $showauthor ) {
			if ( function_exists( 'get_field' ) ) {
				$linktoauthor = get_field( 'dbacf_post_link_author' );
			} else {
				$linktoauthor = get_post_meta( get_the_ID(), 'dbacf_post_link_author', true );
			}
			if ( $showpostdate ) { // post date is shown
				if ( $linktoauthor ) {
					$byline = sprintf(
						/* translators: 1: by */
						esc_html_x( ' by %s', 'post author', 'dfu-busacc' ),
						'<span class="author vcard" itemscope itemtype="http://schema.org/Person" itemprop="author"><a class="dba-link url fn n" rel="author" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" itemprop="url"><span itemprop="name">' . esc_html( get_the_author() ) . '</span></a></span>'
					);
				} else {
					$byline = sprintf(
					/* translators: 1: by */
					esc_html_x( ' by %s', 'post author', 'dfu-busacc' ),
						'<span class="author vcard" itemscope itemtype="http://schema.org/Person" itemprop="author"><span itemprop="name">' . esc_html( get_the_author() ) . '</span></span>'
					);
				}
			} else {
				if ( $linktoauthor ) {
					$byline = sprintf(
					/* translators: 1: Posted by */
					esc_html_x( 'Posted by %s', 'post author', 'dfu-busacc' ),
						'<span class="author vcard" itemscope itemtype="http://schema.org/Person" itemprop="author"><a class="dba-link url fn n" rel="author" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" itemprop="url"><span itemprop="name">' . esc_html( get_the_author() ) . '</span></a></span>'
					);
				} else {
					$byline = sprintf(
					/* translators: 1: Posted by */
					esc_html_x( 'Posted by %s', 'post author', 'dfu-busacc' ),
						'<span class="author vcard" itemscope itemtype="http://schema.org/Person" itemprop="author"><span itemprop="name">' . esc_html( get_the_author() ) . '</span></span>'
					);
				}
			}
			if ( $showheadicon && true == $showheadicon ) {
				if ( true == get_theme_mod( 'dba_load_fa', true ) ) {
					$postedbyicon = apply_filters( 'dfu_busacc_f_postedby_faicon', '<i class="fas fa-user fa-fw" aria-hidden="true"></i>' );
					$byline = ( $showpostdate ? '&nbsp;' : '' ) . '<span class="dba-bloghead-ico">' . wp_kses_post( $postedbyicon ) . '</span>' . $byline;
				} else {
					$postedbyicon = apply_filters( 'dfu_busacc_f_postedby_icon', '<span class="iconmoon-dk ico-user"></span>' );
					$byline = ( $showpostdate ? '&nbsp;' : '' ) . '<span class="dba-bloghead-ico">' . wp_kses_post( $postedbyicon ) . '</span>' . $byline;
				}
			}
			echo '<span class="byline">' . $byline . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}
}

/**
 * Prints HTML with meta information for the categories, tags and comments.
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_blog_footer' ) ) {
	function dfu_busacc_fn_blog_footer() {
		if ( function_exists( 'get_field' ) ) {
			$showcat = get_field( 'dbacf_post_show_category' );
			$showtag = get_field( 'dbacf_post_show_tags' );
		} else {
			$showcat = get_post_meta( get_the_ID(), 'dbacf_post_show_category', true );
			$showtag = get_post_meta( get_the_ID(), 'dbacf_post_show_tags', true );
		}
		$showfooticon = get_theme_mod( 'dba_blog_show_footer_ico' );

		if ( $showfooticon && true == $showfooticon ) {
			if ( true == get_theme_mod( 'dba_load_fa', true ) ) {
				$caticon = apply_filters( 'dfu_busacc_f_cat_faicon', '<i class="fas fa-bookmark fa-fw" aria-hidden="true"></i>' );
				$catline = '<span class="dba-blogfoot-ico">' . wp_kses_post( $caticon ) . '&nbsp;</span>';
			} else {
				$caticon = apply_filters( 'dfu_busacc_f_cat_icon', '<span class="iconmoon-dk ico-bookmark"></span>' );
				$catline = '<span class="dba-blogfoot-ico">' . wp_kses_post( $caticon ) . '&nbsp;</span>';
			}
			if ( true == get_theme_mod( 'dba_load_fa', true ) ) {
				$tagicon = apply_filters( 'dfu_busacc_f_tag_faicon', '<i class="fas fa-tags fa-fw" aria-hidden="true"></i>' );
				$tagline = '<span class="dba-blogfoot-ico">' . wp_kses_post( $tagicon ) . '&nbsp;</span>';
			} else {
				$tagicon = apply_filters( 'dfu_busacc_f_tag_icon', '<span class="iconmoon-dk ico-price-tag"></span>' );
				$tagline = '<span class="dba-blogfoot-ico">' . wp_kses_post( $tagicon ) . '&nbsp;</span>';
			}
		} else {
			$catline = '';
			$tagline = '';
		}

		// category and tag text for posts only.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			if ( $showcat ) {
				$categories_list = get_the_category_list( esc_html__( ', ', 'dfu-busacc' ) );
				if ( $categories_list ) {
					/* translators: 1: list of categories. */
					printf( '<div class="cat-links">' . wp_kses_post( $catline ) . esc_html__( 'Posted in %1$s', 'dfu-busacc' ) . '</div>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				}
			}

			/* translators: used between list items, there is a space after the comma */
			if ( $showtag ) {
				$tagusebadge = get_theme_mod( 'dba_blog_tag_use_badge', false );
				if ( $tagusebadge ) {
					$tags_list = get_the_tag_list( '<span class="badge badge-pill dba-badge-link">', '</span>&nbsp;<span class="badge badge-pill dba-badge-link">' );
				} else {
					$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'dfu-busacc' ) );
				}
				if ( $tags_list ) {
					/* translators: 1: list of tags. */
					printf( '<div class="tag-links">' . wp_kses_post( $tagline ) . esc_html__( 'Tagged %1$s', 'dfu-busacc' ) . '</div>', $tags_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					?>
					<meta itemprop="keywords" content="<?php echo esc_attr( strip_tags( get_the_tag_list('',' , ','') ) ); ?>">
				<?php
				}
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<div class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'dfu-busacc' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</div>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'dfu-busacc' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<div class="edit-link">',
			'</div>'
		);
	}
}

/**
 * Get ACF group fields without ACF
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_get_group_fields' ) ) {
	function dfu_busacc_fn_get_group_fields( $group_name ) {
		$group = get_page_by_title( html_entity_decode( $group_name ), OBJECT, 'acf' );
		if ( empty( $group ) ) {
			return false;
		}
		$meta = get_post_meta( $group->ID );
		$acf_fields = array();
		foreach ( $meta as $key => $value ) {
			$acf_meta_key = stristr( $key, 'field_' ); // acf fields all start with "field_"
			if ( $acf_meta_key ) {
				$acf_fields[] = get_field_object( $key );
			}
		}
		return $acf_fields; // returns an array of field objects
	}
}

/**
 * Get theme colours based on primary and/or secondary colour(s)
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_theme_colours' ) ) {
	function dfu_busacc_fn_theme_colours( $pri, $sec = '' ) {
		$colors = array();
		$colors['pri'] = $pri;
		if ( '' == $sec ) {
			$sec = dfu_busacc_fn_getcomplementarycolour( $pri );
		}
		$colors['sec'] = $sec;
		$themetype = dfu_busacc_fn_colourcheck( $pri );
		if ( 'dk' == $themetype ) {
			$colors['pri_lt20'] = dfu_busacc_fn_hextint( $pri, 0.2, 't' );
			$colors['pri_lt65'] = dfu_busacc_fn_hextint( $pri, 0.65, 't' );
			$colors['pri_lt75'] = dfu_busacc_fn_hextint( $pri, 0.75, 't' );
			$colors['pri_lt85'] = dfu_busacc_fn_hextint( $pri, 0.85, 't' );
			$colors['pri_lt90'] = dfu_busacc_fn_hextint( $pri, 0.9, 't' );
			$colors['pri_lt95'] = dfu_busacc_fn_hextint( $pri, 0.95, 't' );
			$colors['pri_dk30'] = dfu_busacc_fn_hextint( $pri, 0.3, 's' );
			$colors['pri_dk40'] = dfu_busacc_fn_hextint( $pri, 0.4, 's' );

			$colors['sec_lt60'] = dfu_busacc_fn_hextint( $sec, 0.6, 't' );
			$colors['sec_lt70'] = dfu_busacc_fn_hextint( $sec, 0.7, 't' );
			$colors['sec_lt80'] = dfu_busacc_fn_hextint( $sec, 0.8, 't' );
			$colors['sec_lt90'] = dfu_busacc_fn_hextint( $sec, 0.9, 't' );
			$colors['sec_lt95'] = dfu_busacc_fn_hextint( $sec, 0.95, 't' );
			$colors['sec_dk30'] = dfu_busacc_fn_hextint( $sec, 0.3, 's' );
			$colors['sec_dk40'] = dfu_busacc_fn_hextint( $sec, 0.4, 's' );
			$colors['pri_txt'] = dfu_busacc_fn_getcontrastcolour( $pri, 1 );
			$colors['pri_txt_dk'] = dfu_busacc_fn_getcontrastcolour( $pri, 2 );
		} elseif ( 'lt' == $themetype ) {
			$colors['pri_lt20'] = dfu_busacc_fn_hextint( $pri, 0.8, 's' );
			$colors['pri_lt65'] = dfu_busacc_fn_hextint( $pri, 0.7, 's' );
			$colors['pri_lt75'] = dfu_busacc_fn_hextint( $pri, 0.6, 's' );
			$colors['pri_lt85'] = dfu_busacc_fn_hextint( $pri, 0.5, 's' );
			$colors['pri_lt90'] = dfu_busacc_fn_hextint( $pri, 0.85, 't' );
			$colors['pri_lt95'] = dfu_busacc_fn_hextint( $pri, 0.95, 't' );
			$colors['pri_dk30'] = dfu_busacc_fn_hextint( $pri, 0.4, 't' );
			$colors['pri_dk40'] = dfu_busacc_fn_hextint( $pri, 0.3, 't' );

			$colors['sec_lt60'] = dfu_busacc_fn_hextint( $sec, 0.65, 't' );
			$colors['sec_lt70'] = dfu_busacc_fn_hextint( $sec, 0.55, 's' );
			$colors['sec_lt80'] = dfu_busacc_fn_hextint( $sec, 0.45, 's' );
			$colors['sec_lt90'] = dfu_busacc_fn_hextint( $sec, 0.35, 's' );
			$colors['sec_lt95'] = dfu_busacc_fn_hextint( $sec, 0.95, 't' );
			$colors['sec_dk30'] = dfu_busacc_fn_hextint( $sec, 0.4, 't' );
			$colors['sec_dk40'] = dfu_busacc_fn_hextint( $sec, 0.3, 't' );
			$colors['pri_txt'] = dfu_busacc_fn_getcontrastcolour( $pri, 1 );
			$colors['pri_txt_dk'] = dfu_busacc_fn_getcontrastcolour( $pri, 2 );
		}
		return $colors;
	}
}

/**
 * Get footer icon background light or dark
 *******************************************************************************************************************************************/
if ( ! function_exists( 'dfu_busacc_fn_footer_iconbg' ) ) {
	function dfu_busacc_fn_footer_iconbg() {
		$btngrad = get_theme_mod( 'dba_btn_grad', false );
		if ( $btngrad ) {
			$btnbgcolor = get_theme_mod( 'dba_btn_first' );
		} else {
			$btndefault = array(
				'text'  => '#f0f1f2',
				'htext' => '#fcfcfc',
				'bg'    => '#0088cc',
				'hbg'   => '#006191',
			);
			$btncol = get_theme_mod( 'dba_button', $btndefault );
			$btnbgcolor = $btncol['bg'];
		}
		$ctype = dfu_busacc_fn_colourcheck( $btnbgcolor );
		$iconbgcolor = ( 'lt' == $ctype ? 'dk' : 'lt' );
		return $iconbgcolor;
	}
}

if ( ! function_exists( 'dfu_busacc_fn_default_header_slider' ) ) {
	function dfu_busacc_fn_default_header_slider() {
		$dfu_busacc_headerimgs[1] = '/inc/assets/img/1046491-pxhere.jpg';
		$dfu_busacc_headerimgs[2] = '/inc/assets/img/334581-pxhere.jpg';
		$dfu_busacc_j = 0;
		foreach ( $dfu_busacc_headerimgs as $dfu_busacc_headerimg ) {
		?>
			<div class="carousel-item<?php echo ( 0 == $dfu_busacc_j ? ' active' : '' ); ?>">
			<?php
			$width = 2000;
			$height = 1200;
			$imghtml = '<img class="d-block w-100" src="' . get_parent_theme_file_uri( $dfu_busacc_headerimg ) . '" width="' . $width . '" height="' . $height . '">';
			echo wp_kses_post( $imghtml ); ?>
			</div>
		<?php
			$dfu_busacc_j++;
		}
	}
}

?>
